/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[DG Business Unit](
	[Business Unit Acronym EN] [char](64) NOT NULL,
	[Business Unit Acronym 2NDL] [char](64) NOT NULL,
	[Business Unit Full Name EN] [char](256) NOT NULL,
	[Business Unit Full Name 2NDL] [char](256) NOT NULL,
	[Parent Business Unit Acronym EN] [char](64) NOT NULL,
	[Business Unit Hyperlink EN] [varchar](8000) NOT NULL,
	[Business Unit Hyperlink 2NDL] [varchar](8000) NOT NULL,
	[Business Unit Type EN] [char](64) NOT NULL,
	[Part Of Organization Code EN] [char](64) NOT NULL,
	[Required In Data Gov Committees Indicator EN] [char](64) NOT NULL,
	[Business Unit Notes EN] [varchar](8000) NOT NULL,
	[Business Unit Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [DG Business Unit_PK] PRIMARY KEY CLUSTERED 
(
	[Business Unit Acronym EN] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Unit Acronym EN]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Unit Acronym 2NDL]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Unit Full Name EN]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Unit Full Name 2NDL]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Parent Business Unit Acronym EN]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Unit Hyperlink EN]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Unit Hyperlink 2NDL]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Unit Type EN]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Part Of Organization Code EN]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] ADD  DEFAULT ('TBD') FOR [Required In Data Gov Committees Indicator EN]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Unit Notes EN]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Unit Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit]  WITH CHECK ADD  CONSTRAINT [DG Business Unit_Code Business Unit Type_FK] FOREIGN KEY([Business Unit Type EN])
REFERENCES [IBG_Schema].[Code Business Unit Type] ([Business Unit Type EN])
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] CHECK CONSTRAINT [DG Business Unit_Code Business Unit Type_FK]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit]  WITH CHECK ADD  CONSTRAINT [DG Business Unit_Code Part Of Organization_FK] FOREIGN KEY([Part Of Organization Code EN])
REFERENCES [IBG_Schema].[Code Part Of Organization] ([Part Of Organization Code EN])
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] CHECK CONSTRAINT [DG Business Unit_Code Part Of Organization_FK]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit]  WITH CHECK ADD  CONSTRAINT [DG Business Unit_Code Yes No_FK] FOREIGN KEY([Required In Data Gov Committees Indicator EN])
REFERENCES [IBG_Schema].[Code Yes No] ([Yes No Code EN])
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] CHECK CONSTRAINT [DG Business Unit_Code Yes No_FK]
GO

ALTER TABLE [IBG_Schema].[DG Business Unit]  WITH CHECK ADD  CONSTRAINT [DG Business Unit_DG Business Unit_FK] FOREIGN KEY([Parent Business Unit Acronym EN])
REFERENCES [IBG_Schema].[DG Business Unit] ([Business Unit Acronym EN])
GO

ALTER TABLE [IBG_Schema].[DG Business Unit] CHECK CONSTRAINT [DG Business Unit_DG Business Unit_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View DG Business Unit]
GO

CREATE view 
 [IBG_Schema].[View DG Business Unit]
(
[Business Unit Acronym EN]
      ,[Business Unit Acronym FR]
      ,[Business Unit Full Name EN]
      ,[Business Unit Full Name FR]
      ,[Parent Business Unit Acronym EN]
      ,[Business Unit Hyperlink EN]
      ,[Business Unit Hyperlink FR]
      ,[Business Unit Type EN]
      ,[Part Of Organization Code EN]
      ,[Required In Data Gov Committees Indicator EN]
      ,[Business Unit Notes EN]
      ,[Business Unit Notes FR]
      ,[IBG Create Date Time]
)

AS

SELECT [Business Unit Acronym EN]
      ,[Business Unit Acronym 2NDL]
      ,[Business Unit Full Name EN]
      ,[Business Unit Full Name 2NDL]
      ,[Parent Business Unit Acronym EN]
      ,[Business Unit Hyperlink EN]
      ,[Business Unit Hyperlink 2NDL]
      ,[Business Unit Type EN]
      ,[Part Of Organization Code EN]
      ,[Required In Data Gov Committees Indicator EN]
      ,[Business Unit Notes EN]
      ,[Business Unit Notes 2NDL]
      ,[IBG Create Date Time]
  FROM [IBG_Schema].[DG Business Unit]

GO