/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[DG Committee Membership](
	[Committee Acronym EN] [char](64) NOT NULL,
	[Person Name] [char](128) NOT NULL,
	[Committee Membership Role Code EN] [char](64) NOT NULL,
	[Committee Membership Start Date] [date] NOT NULL,
	[Committee Membership End Date] [date] NOT NULL,
	[Notes EN] [varchar](8000) NOT NULL,
	[Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [DG Committee Membership_PK] PRIMARY KEY CLUSTERED 
(
	[Committee Acronym EN] ASC,
	[Person Name] ASC,
	[Committee Membership Role Code EN] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[DG Committee Membership] ADD  DEFAULT ('ZZ To Be Determined') FOR [Committee Acronym EN]
GO

ALTER TABLE [IBG_Schema].[DG Committee Membership] ADD  DEFAULT ('ZZ To Be Determined') FOR [Person Name]
GO

ALTER TABLE [IBG_Schema].[DG Committee Membership] ADD  DEFAULT ('ZZ To Be Determined') FOR [Committee Membership Role Code EN]
GO

ALTER TABLE [IBG_Schema].[DG Committee Membership] ADD  DEFAULT ('ZZ To Be Determined') FOR [Notes EN]
GO

ALTER TABLE [IBG_Schema].[DG Committee Membership] ADD  DEFAULT ('ZZ To Be Determined') FOR [Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[DG Committee Membership] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[DG Committee Membership]  WITH CHECK ADD  CONSTRAINT [DG Committee Membership_Code Committee Membership Role_FK] FOREIGN KEY([Committee Membership Role Code EN])
REFERENCES [IBG_Schema].[Code Committee Membership Role] ([Committee Membership Role Code EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG Committee Membership] CHECK CONSTRAINT [DG Committee Membership_Code Committee Membership Role_FK]
GO

ALTER TABLE [IBG_Schema].[DG Committee Membership]  WITH CHECK ADD  CONSTRAINT [DG Committee Membership_Code Committee_FK] FOREIGN KEY([Committee Acronym EN])
REFERENCES [IBG_Schema].[Code Committee] ([Committee Acronym EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG Committee Membership] CHECK CONSTRAINT [DG Committee Membership_Code Committee_FK]
GO

ALTER TABLE [IBG_Schema].[DG Committee Membership]  WITH CHECK ADD  CONSTRAINT [DG Committee Membership_DG Person_FK] FOREIGN KEY([Person Name])
REFERENCES [IBG_Schema].[DG Person] ([Person Name])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG Committee Membership] CHECK CONSTRAINT [DG Committee Membership_DG Person_FK]
GO

--*************************************************************

CREATE view 
 [IBG_Schema].[View DG Committee Membership]
(
       [Committee Acronym EN]
      ,[Person Name]
      ,[Person Email Address]
      ,[Committee Membership Role Code EN]
      ,[Committee Membership Start Date]
      ,[Committee Membership End Date]
      ,[Notes EN]
      ,[Notes FR]
      ,[IBG Create Date Time]
)

AS

SELECT [Committee Acronym EN]
      ,[DG Committee Membership].[Person Name]
      ,[Person Email Address]
      ,[Committee Membership Role Code EN]
      ,[Committee Membership Start Date]
      ,[Committee Membership End Date]
      ,[Notes EN]
      ,[Notes 2NDL]
      ,[DG Committee Membership].[IBG Create Date Time]
  FROM [IBG_Schema].[DG Committee Membership]
      ,[IBG_Schema].[DG Person]
WHERE
       [DG Committee Membership].[Person Name] = [DG Person].[Person Name]

GO