/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO


CREATE TABLE [IBG_Schema].[DG Data Issue And Business Unit](
	[Data Issue ID] [int] NOT NULL,
	[Data Issue Impact Code EN] [char](64) NOT NULL,
	[Business Unit Acronym EN] [char](64) NOT NULL,
	[Point Of Contact Person Name] [char](128) NOT NULL,
	[Data Issue Impact Notes EN] [varchar](8000) NOT NULL,
	[Data Issue Impact Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [DG Data Issue And Business Unit_PK] PRIMARY KEY CLUSTERED 
(
	[Data Issue ID] ASC,
	[Data Issue Impact Code EN] ASC,
	[Business Unit Acronym EN] ASC,
	[Point Of Contact Person Name] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue And Business Unit] ADD  DEFAULT ((0)) FOR [Data Issue ID]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue And Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue Impact Code EN]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue And Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Unit Acronym EN]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue And Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Point Of Contact Person Name]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue And Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue Impact Notes EN]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue And Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue Impact Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue And Business Unit] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue And Business Unit]  WITH CHECK ADD  CONSTRAINT [DG Data Issue And Business Unit_Code Data Issue Impact_FK] FOREIGN KEY([Data Issue Impact Code EN])
REFERENCES [IBG_Schema].[Code Data Issue Impact] ([Data Issue Impact Code EN])
GO

ALTER TABLE [IBG_Schema].[DG Data Issue And Business Unit] CHECK CONSTRAINT [DG Data Issue And Business Unit_Code Data Issue Impact_FK]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue And Business Unit]  WITH CHECK ADD  CONSTRAINT [DG Data Issue And Business Unit_DG Business Unit_FK] FOREIGN KEY([Business Unit Acronym EN])
REFERENCES [IBG_Schema].[DG Business Unit] ([Business Unit Acronym EN])
GO

ALTER TABLE [IBG_Schema].[DG Data Issue And Business Unit] CHECK CONSTRAINT [DG Data Issue And Business Unit_DG Business Unit_FK]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue And Business Unit]  WITH CHECK ADD  CONSTRAINT [DG Data Issue And Business Unit_DG Data Issue Register_FK] FOREIGN KEY([Data Issue ID])
REFERENCES [IBG_Schema].[DG Data Issue Register] ([Data Issue ID])
GO

ALTER TABLE [IBG_Schema].[DG Data Issue And Business Unit] CHECK CONSTRAINT [DG Data Issue And Business Unit_DG Data Issue Register_FK]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue And Business Unit]  WITH CHECK ADD  CONSTRAINT [DG Data Issue And Business Unit_DG Person_FK] FOREIGN KEY([Point Of Contact Person Name])
REFERENCES [IBG_Schema].[DG Person] ([Person Name])
GO

ALTER TABLE [IBG_Schema].[DG Data Issue And Business Unit] CHECK CONSTRAINT [DG Data Issue And Business Unit_DG Person_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View DG Data Issue And Business Unit]
GO

CREATE view 
 [IBG_Schema].[View DG Data Issue And Business Unit]
(
[Data Issue ID]
      ,[Data Issue Impact Code EN]
      ,[Business Unit Acronym EN]
      ,[Point Of Contact Person Name]
      ,[Data Issue Impact Notes EN]
      ,[Data Issue Impact Notes FR]
      ,[IBG Create Date Time]
)

AS

SELECT [Data Issue ID]
      ,[Data Issue Impact Code EN]
      ,[Business Unit Acronym EN]
      ,[Point Of Contact Person Name]
      ,[Data Issue Impact Notes EN]
      ,[Data Issue Impact Notes 2NDL]
      ,[IBG Create Date Time]
  FROM [IBG_Schema].[DG Data Issue And Business Unit]

GO