/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[DG Data Issue Register](
	[Data Issue ID] [int] NOT NULL,
	[Data Issue Title EN] [char](256) NOT NULL,
	[Data Issue Title 2NDL] [char](256) NOT NULL,
	[Data Issue Description EN] [varchar](8000) NOT NULL,
	[Data Issue Description 2NDL] [varchar](8000) NOT NULL,
	[Data Issue Documentation Folder Hyperlink] [varchar](8000) NOT NULL,
	[Data Issue Category Code EN] [char](64) NOT NULL,
	[Data Issue Severity Code EN] [char](64) NOT NULL,
	[Data Issue Priority Code] [int] NOT NULL,
	[Data Issue Identification Date] [date] NOT NULL,
	[Data Issue Notes EN] [varchar](8000) NOT NULL,
	[Data Issue Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [DG Data Issue Register_PK] PRIMARY KEY CLUSTERED 
(
	[Data Issue ID] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register] ADD  DEFAULT ((0)) FOR [Data Issue ID]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue Title EN]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue Title 2NDL]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue Description EN]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue Description 2NDL]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue Documentation Folder Hyperlink]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue Category Code EN]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue Severity Code EN]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register] ADD  DEFAULT ((0)) FOR [Data Issue Priority Code]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register] ADD  DEFAULT (getdate()) FOR [Data Issue Identification Date]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue Notes EN]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register]  WITH CHECK ADD  CONSTRAINT [DG Data Issue Register_Code Data Issue Category_FK] FOREIGN KEY([Data Issue Category Code EN])
REFERENCES [IBG_Schema].[Code Data Issue Category] ([Data Issue Category Code EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register] CHECK CONSTRAINT [DG Data Issue Register_Code Data Issue Category_FK]
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register]  WITH CHECK ADD  CONSTRAINT [DG Data Issue Register_Code Data Issue Severity_FK] FOREIGN KEY([Data Issue Severity Code EN])
REFERENCES [IBG_Schema].[Code Data Issue Severity] ([Data Issue Severity Code EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG Data Issue Register] CHECK CONSTRAINT [DG Data Issue Register_Code Data Issue Severity_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View DG Data Issue Register]
GO

CREATE view 
 [IBG_Schema].[View DG Data Issue Register]
(
[Data Issue ID]
      ,[Data Issue Title EN]
      ,[Data Issue Title FR]
      ,[Data Issue Description EN]
      ,[Data Issue Description FR]
      ,[Data Issue Documentation Folder Hyperlink]
      ,[Data Issue Category Code EN]
      ,[Data Issue Severity Code EN]
      ,[Data Issue Priority Code]
      ,[Data Issue Identification Date]
      ,[Data Issue Notes EN]
      ,[Data Issue Notes FR]
      ,[IBG Create Date Time]
)

AS

SELECT [Data Issue ID]
      ,[Data Issue Title EN]
      ,[Data Issue Title 2NDL]
      ,[Data Issue Description EN]
      ,[Data Issue Description 2NDL]
      ,[Data Issue Documentation Folder Hyperlink]
      ,[Data Issue Category Code EN]
      ,[Data Issue Severity Code EN]
      ,[Data Issue Priority Code]
      ,[Data Issue Identification Date]
      ,[Data Issue Notes EN]
      ,[Data Issue Notes 2NDL]
      ,[IBG Create Date Time]
  FROM [IBG_Schema].[DG Data Issue Register]

GO