/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[DG Person](
	[Person Name] [char](128) NOT NULL,
	[Reports To Person Name] [char](128) NOT NULL,
	[Person Email Address] [char](256) NOT NULL,
	[Job Title Role EN] [char](256) NOT NULL,
	[Job Title Role 2NDL] [char](256) NOT NULL,
	[Business Unit Acronym EN] [char](64) NOT NULL,
	[Person Notes EN] [varchar](8000) NOT NULL,
	[Person Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [DG Person_PK] PRIMARY KEY CLUSTERED 
(
	[Person Name] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[DG Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [Person Name]
GO

ALTER TABLE [IBG_Schema].[DG Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [Reports To Person Name]
GO

ALTER TABLE [IBG_Schema].[DG Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [Person Email Address]
GO

ALTER TABLE [IBG_Schema].[DG Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [Job Title Role EN]
GO

ALTER TABLE [IBG_Schema].[DG Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [Job Title Role 2NDL]
GO

ALTER TABLE [IBG_Schema].[DG Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Unit Acronym EN]
GO

ALTER TABLE [IBG_Schema].[DG Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [Person Notes EN]
GO

ALTER TABLE [IBG_Schema].[DG Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [Person Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[DG Person] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[DG Person]  WITH CHECK ADD  CONSTRAINT [DG Person_DG Business Unit_FK] FOREIGN KEY([Business Unit Acronym EN])
REFERENCES [IBG_Schema].[DG Business Unit] ([Business Unit Acronym EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG Person] CHECK CONSTRAINT [DG Person_DG Business Unit_FK]
GO

ALTER TABLE [IBG_Schema].[DG Person]  WITH CHECK ADD  CONSTRAINT [DG Person_DG Person_FK] FOREIGN KEY([Reports To Person Name])
REFERENCES [IBG_Schema].[DG Person] ([Person Name])
GO

ALTER TABLE [IBG_Schema].[DG Person] CHECK CONSTRAINT [DG Person_DG Person_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View DG Person]
GO

CREATE view 
 [IBG_Schema].[View DG Person]
(
[Person Name]
      ,[Reports To Person Name]
      ,[Person Email Address]
      ,[Job Title Role EN]
      ,[Job Title Role FR]
      ,[Business Unit Acronym EN]
      ,[Person Notes EN]
      ,[Person Notes FR]
      ,[IBG Create Date Time]
)

AS

SELECT [Person Name]
      ,[Reports To Person Name]
      ,[Person Email Address]
      ,[Job Title Role EN]
      ,[Job Title Role 2NDL]
      ,[Business Unit Acronym EN]
      ,[Person Notes EN]
      ,[Person Notes 2NDL]
      ,[IBG Create Date Time]
  FROM [IBG_Schema].[DG Person]

GO