/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[DG RACI Application Software And Business Unit](
	[Application Software Nickname EN] [char](64) NOT NULL,
	[Business Unit Acronym EN] [char](64) NOT NULL,
	[RACI Code EN] [char](64) NOT NULL,
	[RACI Start Date] [date] NOT NULL,
	[RACI End Date] [date] NOT NULL,
	[RACI Notes EN] [varchar](8000) NOT NULL,
	[RACI Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [DG RACI Application Software And Business Unit_PK] PRIMARY KEY CLUSTERED 
(
	[Application Software Nickname EN] ASC,
	[Business Unit Acronym EN] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[DG RACI Application Software And Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Application Software Nickname EN]
GO

ALTER TABLE [IBG_Schema].[DG RACI Application Software And Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Unit Acronym EN]
GO

ALTER TABLE [IBG_Schema].[DG RACI Application Software And Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [RACI Code EN]
GO

ALTER TABLE [IBG_Schema].[DG RACI Application Software And Business Unit] ADD  DEFAULT ('0001-01-01') FOR [RACI Start Date]
GO

ALTER TABLE [IBG_Schema].[DG RACI Application Software And Business Unit] ADD  DEFAULT ('9999-12-31') FOR [RACI End Date]
GO

ALTER TABLE [IBG_Schema].[DG RACI Application Software And Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [RACI Notes EN]
GO

ALTER TABLE [IBG_Schema].[DG RACI Application Software And Business Unit] ADD  DEFAULT ('ZZ To Be Determined') FOR [RACI Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[DG RACI Application Software And Business Unit] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[DG RACI Application Software And Business Unit]  WITH CHECK ADD  CONSTRAINT [DG RACI Application Software And Business Unit_IBG Application Software_FK] FOREIGN KEY([Application Software Nickname EN])
REFERENCES [IBG_Schema].[IBG Application Software] ([Application Software Nickname EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG RACI Application Software And Business Unit] CHECK CONSTRAINT [DG RACI Application Software And Business Unit_IBG Application Software_FK]
GO

ALTER TABLE [IBG_Schema].[DG RACI Application Software And Business Unit]  WITH CHECK ADD  CONSTRAINT [DG RACI Application Software And Business Unit_DG Business Unit_FK] FOREIGN KEY([Business Unit Acronym EN])
REFERENCES [IBG_Schema].[DG Business Unit] ([Business Unit Acronym EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG RACI Application Software And Business Unit] CHECK CONSTRAINT [DG RACI Application Software And Business Unit_DG Business Unit_FK]
GO

ALTER TABLE [IBG_Schema].[DG RACI Application Software And Business Unit]  WITH CHECK ADD  CONSTRAINT [DG RACI Application Software And Business Unit_Code RACI_FK] FOREIGN KEY([RACI Code EN])
REFERENCES [IBG_Schema].[Code RACI] ([RACI Code EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG RACI Application Software And Business Unit] CHECK CONSTRAINT [DG RACI Application Software And Business Unit_Code RACI_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View DG RACI Application Software And Business Unit]
GO

CREATE view 
 [IBG_Schema].[View DG RACI Application Software And Business Unit]
(
[Application Software Nickname EN]
      ,[Business Unit Acronym EN]
      ,[RACI Code EN]
      ,[RACI Start Date]
      ,[RACI End Date]
      ,[RACI Notes EN]
      ,[RACI Notes FR]
      ,[IBG Create Date Time]
)

AS

SELECT [Application Software Nickname EN]
      ,[Business Unit Acronym EN]
      ,[RACI Code EN]
      ,[RACI Start Date]
      ,[RACI End Date]
      ,[RACI Notes EN]
      ,[RACI Notes 2NDL]
      ,[IBG Create Date Time]
  FROM [IBG_Schema].[DG RACI Application Software And Business Unit]

GO