/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[DG RACI BI Object and Person](
	[BI Object Name EN] [char](64) NOT NULL,
	[BI Object Type EN] [char](64) NOT NULL,
	[BI Accountable Business Unit Acronym EN] [char](64) NOT NULL,
	[RACI Person Name] [char](128) NOT NULL,
	[RACI Code EN] [char](64) NOT NULL,
	[Data Governance Role Code EN] [char](64) NOT NULL,
	[RACI Start Date] [date] NOT NULL,
	[RACI End Date] [date] NOT NULL,
	[RACI Notes EN] [varchar](8000) NOT NULL,
	[RACI Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date] [datetime] NOT NULL,
 CONSTRAINT [DG RACI BI Object and Person_PK] PRIMARY KEY CLUSTERED 
(
	[BI Object Name EN] ASC,
	[BI Object Type EN] ASC,
	[BI Accountable Business Unit Acronym EN] ASC,
	[RACI Person Name] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [BI Object Name EN]
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [BI Object Type EN]
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [BI Accountable Business Unit Acronym EN]
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [RACI Person Name]
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [RACI Code EN]
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Governance Role Code EN]
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person] ADD  DEFAULT ('0001-01-01') FOR [RACI Start Date]
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person] ADD  DEFAULT ('9999-12-31') FOR [RACI End Date]
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [RACI Notes EN]
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [RACI Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person] ADD  DEFAULT (getdate()) FOR [IBG Create Date]
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person]  WITH CHECK ADD  CONSTRAINT [DG RACI BI Object and Person_Code Data Governance Role_FK] FOREIGN KEY([Data Governance Role Code EN])
REFERENCES [IBG_Schema].[Code Data Governance Role] ([Data Governance Role Code EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person] CHECK CONSTRAINT [DG RACI BI Object and Person_Code Data Governance Role_FK]
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person]  WITH CHECK ADD  CONSTRAINT [DG RACI BI Object and Person_Code RACI_FK] FOREIGN KEY([RACI Code EN])
REFERENCES [IBG_Schema].[Code RACI] ([RACI Code EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person] CHECK CONSTRAINT [DG RACI BI Object and Person_Code RACI_FK]
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person]  WITH CHECK ADD  CONSTRAINT [DG RACI BI Object and Person_DG Person_FK] FOREIGN KEY([RACI Person Name])
REFERENCES [IBG_Schema].[DG Person] ([Person Name])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person] CHECK CONSTRAINT [DG RACI BI Object and Person_DG Person_FK]
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person]  WITH CHECK ADD  CONSTRAINT [DG RACI BI Object and Person_IBG Business Intelligence Object_FK] FOREIGN KEY([BI Object Name EN], [BI Object Type EN], [BI Accountable Business Unit Acronym EN])
REFERENCES [IBG_Schema].[IBG Business Intelligence Object] ([BI Object Name EN], [BI Object Type EN], [BI Accountable Business Unit Acronym EN])
-- Does not like "ON UPDATE CASCADE"
GO

ALTER TABLE [IBG_Schema].[DG RACI BI Object and Person] CHECK CONSTRAINT [DG RACI BI Object and Person_IBG Business Intelligence Object_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View DG RACI BI Object and Person]
GO

CREATE view 
 [IBG_Schema].[View DG RACI BI Object and Person]
(
[BI Object Name EN]
      ,[BI Object Type EN]
      ,[BI Accountable Business Unit Acronym EN]
      ,[RACI Person Name]
      ,[RACI Code EN]
      ,[Data Governance Role Code EN]
      ,[RACI Start Date]
      ,[RACI End Date]
      ,[RACI Notes EN]
      ,[RACI Notes FR]
      ,[IBG Create Date]
)

AS

SELECT [BI Object Name EN]
      ,[BI Object Type EN]
      ,[BI Accountable Business Unit Acronym EN]
      ,[RACI Person Name]
      ,[RACI Code EN]
      ,[Data Governance Role Code EN]
      ,[RACI Start Date]
      ,[RACI End Date]
      ,[RACI Notes EN]
      ,[RACI Notes 2NDL]
      ,[IBG Create Date]
  FROM [IBG_Schema].[DG RACI BI Object and Person]

GO