/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[DG RACI Business Attribute And Person](
	[Business Attribute Name EN] [char](64) NOT NULL,
	[Business Entity Name EN] [char](64) NOT NULL,
	[Subject Area Name EN] [char](64) NOT NULL,
	[Person Name] [char](128) NOT NULL,
	[RACI Code EN] [char](64) NOT NULL,
	[Data Governance Role Code EN] [char](64) NOT NULL,
	[RACI Start Date] [date] NOT NULL,
	[RACI End Date] [date] NOT NULL,
	[RACI Notes EN] [varchar](8000) NOT NULL,
	[RACI Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date] [datetime] NOT NULL,
 CONSTRAINT [DG RACI Business Attribute And Person_PK] PRIMARY KEY CLUSTERED 
(
	[Business Attribute Name EN] ASC,
	[Business Entity Name EN] ASC,
	[Subject Area Name EN] ASC,
	[Person Name] ASC,
	[RACI Code EN] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Attribute Name EN]
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Entity Name EN]
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [Subject Area Name EN]
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [Person Name]
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [RACI Code EN]
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Governance Role Code EN]
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person] ADD  DEFAULT ('0001-01-01') FOR [RACI Start Date]
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person] ADD  DEFAULT ('9999-12-31') FOR [RACI End Date]
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [RACI Notes EN]
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person] ADD  DEFAULT ('ZZ To Be Determined') FOR [RACI Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person] ADD  DEFAULT (getdate()) FOR [IBG Create Date]
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person]  WITH CHECK ADD  CONSTRAINT [DG RACI Business Attribute And Person_Code Data Governance Role_FK] FOREIGN KEY([Data Governance Role Code EN])
REFERENCES [IBG_Schema].[Code Data Governance Role] ([Data Governance Role Code EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person] CHECK CONSTRAINT [DG RACI Business Attribute And Person_Code Data Governance Role_FK]
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person]  WITH CHECK ADD  CONSTRAINT [DG RACI Business Attribute And Person_Code RACI_FK] FOREIGN KEY([RACI Code EN])
REFERENCES [IBG_Schema].[Code RACI] ([RACI Code EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person] CHECK CONSTRAINT [DG RACI Business Attribute And Person_Code RACI_FK]
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person]  WITH CHECK ADD  CONSTRAINT [DG RACI Business Attribute And Person_DG Person_FK] FOREIGN KEY([Person Name])
REFERENCES [IBG_Schema].[DG Person] ([Person Name])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person] CHECK CONSTRAINT [DG RACI Business Attribute And Person_DG Person_FK]
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person]  WITH CHECK ADD  CONSTRAINT [DG RACI Business Attribute And Person_IBG Business Attribute Core_FK] FOREIGN KEY([Business Entity Name EN], [Subject Area Name EN], [Business Attribute Name EN])
REFERENCES [IBG_Schema].[IBG Business Attribute Core] ([Business Entity Name EN], [Subject Area Name EN], [Business Attribute Name EN])
-- Does not like "ON UPDATE CASCADE"
GO

ALTER TABLE [IBG_Schema].[DG RACI Business Attribute And Person] CHECK CONSTRAINT [DG RACI Business Attribute And Person_IBG Business Attribute Core_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View DG RACI Business Attribute And Person]
GO

CREATE view 
 [IBG_Schema].[View DG RACI Business Attribute And Person]
(
[Business Attribute Name EN]
      ,[Business Entity Name EN]
      ,[Subject Area Name EN]
      ,[Person Name]
      ,[RACI Code EN]
      ,[Data Governance Role Code EN]
      ,[RACI Start Date]
      ,[RACI End Date]
      ,[RACI Notes EN]
      ,[RACI Notes FR]
      ,[IBG Create Date]
)

AS

SELECT [Business Attribute Name EN]
      ,[Business Entity Name EN]
      ,[Subject Area Name EN]
      ,[Person Name]
      ,[RACI Code EN]
      ,[Data Governance Role Code EN]
      ,[RACI Start Date]
      ,[RACI End Date]
      ,[RACI Notes EN]
      ,[RACI Notes 2NDL]
      ,[IBG Create Date]
  FROM [IBG_Schema].[DG RACI Business Attribute And Person]

GO