/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[DG XREF Data Issue In Other Tracker](
	[Data Issue ID] [int] NOT NULL,
	[Application Software Nickname EN] [char](64) NOT NULL,
	[Data Issue ID In Other Issue Tracking Application] [char](256) NOT NULL,
	[Data Issue Hyperlink In Other Issue Tracking Application] [varchar](8000) NOT NULL,
	[Data Issue XREF Notes EN] [varchar](8000) NOT NULL,
	[Data Issue XREF Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [DG XREF Data Issue In Other Tracker_PK] PRIMARY KEY CLUSTERED 
(
	[Data Issue ID] ASC,
	[Application Software Nickname EN] ASC,
	[Data Issue ID In Other Issue Tracking Application] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[DG XREF Data Issue In Other Tracker] ADD  DEFAULT ((0)) FOR [Data Issue ID]
GO

ALTER TABLE [IBG_Schema].[DG XREF Data Issue In Other Tracker] ADD  DEFAULT ('ZZ To Be Determined') FOR [Application Software Nickname EN]
GO

ALTER TABLE [IBG_Schema].[DG XREF Data Issue In Other Tracker] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue ID In Other Issue Tracking Application]
GO

ALTER TABLE [IBG_Schema].[DG XREF Data Issue In Other Tracker] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue Hyperlink In Other Issue Tracking Application]
GO

ALTER TABLE [IBG_Schema].[DG XREF Data Issue In Other Tracker] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue XREF Notes EN]
GO

ALTER TABLE [IBG_Schema].[DG XREF Data Issue In Other Tracker] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue XREF Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[DG XREF Data Issue In Other Tracker] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[DG XREF Data Issue In Other Tracker]  WITH CHECK ADD  CONSTRAINT [DG XREF Data Issue In Other Tracker_IBG Application Software_FK] FOREIGN KEY([Application Software Nickname EN])
REFERENCES [IBG_Schema].[IBG Application Software] ([Application Software Nickname EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG XREF Data Issue In Other Tracker] CHECK CONSTRAINT [DG XREF Data Issue In Other Tracker_IBG Application Software_FK]
GO

ALTER TABLE [IBG_Schema].[DG XREF Data Issue In Other Tracker]  WITH CHECK ADD  CONSTRAINT [DG XREF Data Issue In Other Tracker_DG Data Issue Register_FK] FOREIGN KEY([Data Issue ID])
REFERENCES [IBG_Schema].[DG Data Issue Register] ([Data Issue ID])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[DG XREF Data Issue In Other Tracker] CHECK CONSTRAINT [DG XREF Data Issue In Other Tracker_DG Data Issue Register_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View DG XREF Data Issue In Other Tracker]
GO

CREATE view 
 [IBG_Schema].[View DG XREF Data Issue In Other Tracker]
(
[Data Issue ID]
      ,[Application Software Nickname EN]
      ,[Data Issue ID In Other Issue Tracking Application]
      ,[Data Issue Hyperlink In Other Issue Tracking Application]
      ,[Data Issue XREF Notes EN]
      ,[Data Issue XREF Notes FR]
      ,[IBG Create Date Time]
)

AS

SELECT [Data Issue ID]
      ,[Application Software Nickname EN]
      ,[Data Issue ID In Other Issue Tracking Application]
      ,[Data Issue Hyperlink In Other Issue Tracking Application]
      ,[Data Issue XREF Notes EN]
      ,[Data Issue XREF Notes 2NDL]
      ,[IBG Create Date Time]
  FROM [IBG_Schema].[DG XREF Data Issue In Other Tracker]

GO