/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[DG-IBG DM Entities](
	[Entity_Name] [char](64) NULL,
	[ObjectID] [char](36) NOT NULL,
	[NumOID] [char](5) NULL,
	[ImportID] [char](64) NULL,
	[ModelID] [char](36) NULL,
	[Num_ModelID] [char](2) NULL,
	[Structured_Type_ID] [char](1) NULL,
	[Num_Structured_Type_ID] [char](36) NULL,
	[Structured_Type_Name] [char](1) NULL,
	[Number_Data_Elements] [char](3) NULL,
	[Classification_Type] [char](1) NULL,
	[Allow_Type_Substitution] [char](1) NULL,
	[Min_Volume] [char](1) NULL,
	[Expected_Volume] [char](1) NULL,
	[Max_Volume] [char](7) NULL,
	[Growth_Rate_Percents] [char](1) NULL,
	[Growth_Rate_Interval] [char](5) NULL,
	[Normal_Form] [char](5) NULL,
	[Temporary_Object_Scope] [char](1) NULL,
	[Adequately_Normalized] [char](1) NULL,
	[Substitution_Parent] [char](1) NULL,
	[Num_Substitution_Parent] [char](1) NULL,
	[Synonyms] [char](64) NULL,
	[Synonym_To_Display] [char](64) NULL,
	[Preferred_Abbreviation] [char](64) NULL,
	[SuperTypeEntity_ID] [char](1) NULL,
	[Num_SuperTypeEntity_ID] [char](1) NULL,
	[Engineering_Strategy] [char](1) NULL,
	[Owner] [char](64) NULL,
	[Entity_Source] [char](1) NULL
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[DG-IBG DM Entities]  WITH CHECK ADD  CONSTRAINT [DG-IBG DM Entities_DG-IBG DM Comments RDBMS_FK] FOREIGN KEY([ObjectID])
REFERENCES [IBG_Schema].[DG-IBG DM Comments RDBMS] ([ObjectID])
GO

ALTER TABLE [IBG_Schema].[DG-IBG DM Entities] CHECK CONSTRAINT [DG-IBG DM Entities_DG-IBG DM Comments RDBMS_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View DG-IBG DM Entities] 
GO

CREATE view 
 [IBG_Schema].[View DG-IBG DM Entities]
(
     Entity_Name, 
     ObjectID , 
     NumOID , 
     ImportID, 
     ModelID , 
     Num_ModelID , 
     Structured_Type_ID , 
     Num_Structured_Type_ID, 
     Structured_Type_Name , 
     Number_Data_Elements , 
     Classification_Type , 
     Allow_Type_Substitution, 
     Min_Volume , 
     Expected_Volume , 
     Max_Volume , 
     Growth_Rate_Percents , 
     Growth_Rate_Interval , 
     Normal_Form , 
     Temporary_Object_Scope , 
     Adequately_Normalized , 
     Substitution_Parent , 
     Num_Substitution_Parent , 
     Synonyms , 
     Synonym_To_Display , 
     Preferred_Abbreviation , 
     SuperTypeEntity_ID , 
     Num_SuperTypeEntity_ID, 
     Engineering_Strategy , 
     Owner , 
     Entity_Source 
)

AS

SELECT 
     Entity_Name, 
     ObjectID , 
     NumOID , 
     ImportID, 
     ModelID , 
     Num_ModelID , 
     Structured_Type_ID , 
     Num_Structured_Type_ID, 
     Structured_Type_Name , 
     Number_Data_Elements , 
     Classification_Type , 
     Allow_Type_Substitution, 
     Min_Volume , 
     Expected_Volume , 
     Max_Volume , 
     Growth_Rate_Percents , 
     Growth_Rate_Interval , 
     Normal_Form , 
     Temporary_Object_Scope , 
     Adequately_Normalized , 
     Substitution_Parent , 
     Num_Substitution_Parent , 
     Synonyms , 
     Synonym_To_Display , 
     Preferred_Abbreviation , 
     SuperTypeEntity_ID , 
     Num_SuperTypeEntity_ID, 
     Engineering_Strategy , 
     Owner , 
     Entity_Source
FROM [IBG_Schema].[DG-IBG DM Entities]

GO

