/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[IBG Business Attribute DQ Colors](
	[DQ Rule Number SKEY] [int] NOT NULL,
	[DQ Color Code EN] [char](64) NOT NULL,
	[DQ Color Low Range Percentage] [int] NOT NULL,
	[DQ Color High Range Percentage] [int] NOT NULL,
	[DQ Color Range Approved By Person Name] [char](128) NOT NULL,
	[DQ Color Range Notes EN] [varchar](8000) NOT NULL,
	[DQ Color Range Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [IBG Business Attribute DQ Colors_PK] PRIMARY KEY CLUSTERED 
(
	[DQ Color Code EN] ASC,
	[DQ Rule Number SKEY] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Colors] ADD  DEFAULT ((0)) FOR [DQ Rule Number SKEY]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Colors] ADD  DEFAULT ('ZZ To Be Determined') FOR [DQ Color Code EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Colors] ADD  DEFAULT ((0)) FOR [DQ Color Low Range Percentage]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Colors] ADD  DEFAULT ((0)) FOR [DQ Color High Range Percentage]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Colors] ADD  DEFAULT ('ZZ To Be Determined') FOR [DQ Color Range Approved By Person Name]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Colors] ADD  DEFAULT ('ZZ To Be Determined') FOR [DQ Color Range Notes EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Colors] ADD  DEFAULT ('ZZ To Be Determined') FOR [DQ Color Range Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Colors] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Colors]  WITH CHECK ADD  CONSTRAINT [IBG Business Attribute DQ Colors_Code DQ Color_FK] FOREIGN KEY([DQ Color Code EN])
REFERENCES [IBG_Schema].[Code DQ Color] ([DQ Color Code EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Colors] CHECK CONSTRAINT [IBG Business Attribute DQ Colors_Code DQ Color_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Colors]  WITH CHECK ADD  CONSTRAINT [IBG Business Attribute DQ Colors_DG Person_FK] FOREIGN KEY([DQ Color Range Approved By Person Name])
REFERENCES [IBG_Schema].[DG Person] ([Person Name])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Colors] CHECK CONSTRAINT [IBG Business Attribute DQ Colors_DG Person_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Colors]  WITH CHECK ADD  CONSTRAINT [IBG Business Attribute DQ Colors_IBG Business Attribute DQ Rules_FK] FOREIGN KEY([DQ Rule Number SKEY])
REFERENCES [IBG_Schema].[IBG Business Attribute DQ Rules] ([DQ Rule Number SKEY])
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Colors] CHECK CONSTRAINT [IBG Business Attribute DQ Colors_IBG Business Attribute DQ Rules_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View IBG Business Attribute DQ Colors]
GO

CREATE view 
 [IBG_Schema].[View IBG Business Attribute DQ Colors]
(
       [DQ Rule Number SKEY]
      ,[DQ Color Code EN]
      ,[DQ Color Low Range Percentage]
      ,[DQ Color High Range Percentage]
      ,[DQ Color Range Approved By Person Name]
      ,[DQ Color Range Notes EN]
      ,[DQ Color Range Notes FR]
      ,[IBG Create Date Time]
)

AS

SELECT [DQ Rule Number SKEY]
      ,[DQ Color Code EN]
      ,[DQ Color Low Range Percentage]
      ,[DQ Color High Range Percentage]
      ,[DQ Color Range Approved By Person Name]
      ,[DQ Color Range Notes EN]
      ,[DQ Color Range Notes 2NDL]
      ,[IBG Create Date Time]
  FROM [IBG_Schema].[IBG Business Attribute DQ Colors]

GO