/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[IBG Business Attribute DQ Rules](
	[DQ Rule Number SKEY] [int] NOT NULL,
	[DQ Dimension Code EN] [char](64) NOT NULL,
	[Business Attribute Name EN] [char](64) NOT NULL,
	[Business Entity Name EN] [char](64) NOT NULL,
	[Subject Area Name EN] [char](64) NOT NULL,
	[DQ Rule Owner Business Unit Acronym EN] [char](64) NOT NULL,
	[DQ Rule Criteria Text EN] [varchar](8000) NOT NULL,
	[DQ Rule Criteria Text 2NDL] [varchar](8000) NOT NULL,
	[DQ Rule Approved By Person Name] [char](128) NOT NULL,
	[DQ Rule Notes EN] [varchar](8000) NOT NULL,
	[DQ Rule Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [IBG Business Attribute DQ Rules_PK] PRIMARY KEY CLUSTERED 
(
	[DQ Rule Number SKEY] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules] ADD  DEFAULT ((0)) FOR [DQ Rule Number SKEY]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules] ADD  DEFAULT ('ZZ To Be Determined') FOR [DQ Dimension Code EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Attribute Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Entity Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules] ADD  DEFAULT ('ZZ To Be Determined') FOR [Subject Area Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules] ADD  DEFAULT ('ZZ To Be Determined') FOR [DQ Rule Owner Business Unit Acronym EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules] ADD  DEFAULT ('ZZ To Be Determined') FOR [DQ Rule Criteria Text EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules] ADD  DEFAULT ('ZZ To Be Determined') FOR [DQ Rule Criteria Text 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules] ADD  DEFAULT ('ZZ To Be Determined') FOR [DQ Rule Approved By Person Name]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules] ADD  DEFAULT ('ZZ To Be Determined') FOR [DQ Rule Notes EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules] ADD  DEFAULT ('ZZ To Be Determined') FOR [DQ Rule Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules]  WITH CHECK ADD  CONSTRAINT [IBG Business Attribute DQ Rules_DG Business Unit_FK] FOREIGN KEY([DQ Rule Owner Business Unit Acronym EN])
REFERENCES [IBG_Schema].[DG Business Unit] ([Business Unit Acronym EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules] CHECK CONSTRAINT [IBG Business Attribute DQ Rules_DG Business Unit_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules]  WITH CHECK ADD  CONSTRAINT [IBG Business Attribute DQ Rules_Code DQ Dimension_FK] FOREIGN KEY([DQ Dimension Code EN])
REFERENCES [IBG_Schema].[Code DQ Dimension] ([DQ Dimension Code EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules] CHECK CONSTRAINT [IBG Business Attribute DQ Rules_Code DQ Dimension_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules]  WITH CHECK ADD  CONSTRAINT [IBG Business Attribute DQ Rules_DG Person_FK] FOREIGN KEY([DQ Rule Approved By Person Name])
REFERENCES [IBG_Schema].[DG Person] ([Person Name])
-- Does Not Like "ON UPDATE CASCADE"
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules] CHECK CONSTRAINT [IBG Business Attribute DQ Rules_DG Person_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules]  WITH CHECK ADD  CONSTRAINT [IBG Business Attribute DQ Rules_IBG Business Attribute Core_FK] FOREIGN KEY([Business Entity Name EN], [Subject Area Name EN], [Business Attribute Name EN])
REFERENCES [IBG_Schema].[IBG Business Attribute Core] ([Business Entity Name EN], [Subject Area Name EN], [Business Attribute Name EN])
-- Does Not Like "ON UPDATE CASCADE"
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute DQ Rules] CHECK CONSTRAINT [IBG Business Attribute DQ Rules_IBG Business Attribute Core_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View IBG Business Attribute DQ Rules]
GO

CREATE view 
 [IBG_Schema].[View IBG Business Attribute DQ Rules]
(
[DQ Rule Number SKEY]
      ,[DQ Dimension Code EN]
      ,[Business Attribute Name EN]
      ,[Business Entity Name EN]
      ,[Subject Area Name EN]
      ,[DQ Rule Owner Business Unit Acronym EN]
      ,[DQ Rule Criteria Text EN]
      ,[DQ Rule Criteria Text FR]
      ,[DQ Rule Approved By Person Name]
      ,[DQ Rule Notes EN]
      ,[DQ Rule Notes FR]
      ,[IBG Create Date Time]
)

AS

SELECT [DQ Rule Number SKEY]
      ,[DQ Dimension Code EN]
      ,[Business Attribute Name EN]
      ,[Business Entity Name EN]
      ,[Subject Area Name EN]
      ,[DQ Rule Owner Business Unit Acronym EN]
      ,[DQ Rule Criteria Text EN]
      ,[DQ Rule Criteria Text 2NDL]
      ,[DQ Rule Approved By Person Name]
      ,[DQ Rule Notes EN]
      ,[DQ Rule Notes 2NDL]
      ,[IBG Create Date Time]
  FROM [IBG_Schema].[IBG Business Attribute DQ Rules]

GO