/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[IBG Business Attribute Document](
	[Business Attribute Name EN] [char](64) NOT NULL,
	[Business Entity Name EN] [char](64) NOT NULL,
	[Subject Area Name EN] [char](64) NOT NULL,
	[Document Name EN] [char](256) NOT NULL,
	[Document Name 2NDL] [char](256) NOT NULL,
	[Document Hyperlink EN] [varchar](8000) NOT NULL,
	[Document Hyperlink 2NDL] [varchar](8000) NOT NULL,
	[Business Attribute Document Notes EN] [varchar](8000) NOT NULL,
	[Business Attribute Document Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [IBG Business Attribute Document_PK] PRIMARY KEY CLUSTERED 
(
	[Business Attribute Name EN] ASC,
	[Business Entity Name EN] ASC,
	[Subject Area Name EN] ASC,
        [Document Name EN] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute Document] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Attribute Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute Document] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Entity Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute Document] ADD  DEFAULT ('ZZ To Be Determined') FOR [Subject Area Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute Document] ADD  DEFAULT ('ZZ To Be Determined') FOR [Document Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute Document] ADD  DEFAULT ('ZZ To Be Determined') FOR [Document Name 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute Document] ADD  DEFAULT ('ZZ To Be Determined') FOR [Document Hyperlink EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute Document] ADD  DEFAULT ('ZZ To Be Determined') FOR [Document Hyperlink 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute Document] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Attribute Document Notes EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute Document] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Attribute Document Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute Document] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute Document]  WITH CHECK ADD  CONSTRAINT [IBG Business Attribute Document_IBG Business Attribute Core_FK] FOREIGN KEY([Business Entity Name EN], [Subject Area Name EN], [Business Attribute Name EN])
REFERENCES [IBG_Schema].[IBG Business Attribute Core] ([Business Entity Name EN], [Subject Area Name EN], [Business Attribute Name EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG Business Attribute Document] CHECK CONSTRAINT [IBG Business Attribute Document_IBG Business Attribute Core_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View IBG Business Attribute Document]
GO

CREATE view 
 [IBG_Schema].[View IBG Business Attribute Document]
(
       [Business Attribute Name EN]
      ,[Business Entity Name EN]
      ,[Subject Area Name EN]
      ,[Document Name EN]
      ,[Document Name FR]
      ,[Document Hyperlink EN]
      ,[Document Hyperlink FR]
      ,[Business Attribute Document Notes EN]
      ,[Business Attribute Document Notes FR]
      ,[IBG Create Date Time]
)

AS

SELECT [Business Attribute Name EN]
      ,[Business Entity Name EN]
      ,[Subject Area Name EN]
      ,[Document Name EN]
      ,[Document Name 2NDL]
      ,[Document Hyperlink EN]
      ,[Document Hyperlink 2NDL]
      ,[Business Attribute Document Notes EN]
      ,[Business Attribute Document Notes 2NDL]
      ,[IBG Create Date Time]
  FROM [IBG_Schema].[IBG Business Attribute Document]

GO