/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[IBG Business Entity](
	[Business Entity Name EN] [char](64) NOT NULL,
	[Subject Area Name EN] [char](64) NOT NULL,
	[Business Entity Name 2NDL] [char](64) NOT NULL,
	[Business Entity Definition EN] [varchar](8000) NOT NULL,
	[Business Entity Definition 2NDL] [varchar](8000) NOT NULL,
	[Business Metadata Status Code EN] [char](64) NOT NULL,
	[Business Metadata Approved By Person Name] [char](128) NOT NULL,
	[Business Metadata Approved Date] [date] NOT NULL,
	[Sensitivity Level Code EN] [char](64) NOT NULL,
	[Protected Level Code EN] [char](64) NOT NULL,
	[Business Entity Notes EN] [varchar](8000) NOT NULL,
	[Business Entity Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [IBG Business Entity_PK] PRIMARY KEY CLUSTERED 
(
	[Business Entity Name EN] ASC,
	[Subject Area Name EN] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Entity Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] ADD  DEFAULT ('ZZ To Be Determined') FOR [Subject Area Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Entity Name 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Entity Definition EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Entity Definition 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Metadata Status Code EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Metadata Approved By Person Name]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] ADD  DEFAULT ('9999-12-31') FOR [Business Metadata Approved Date]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] ADD  DEFAULT ('ZZ To Be Determined') FOR [Sensitivity Level Code EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] ADD  DEFAULT ('ZZ To Be Determined') FOR [Protected Level Code EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Entity Notes EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Entity Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity]  WITH CHECK ADD  CONSTRAINT [IBG Business Entity_Code Business Metadata Status_FK] FOREIGN KEY([Business Metadata Status Code EN])
REFERENCES [IBG_Schema].[Code Business Metadata Status] ([Business Metadata Status Code EN])
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] CHECK CONSTRAINT [IBG Business Entity_Code Business Metadata Status_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity]  WITH CHECK ADD  CONSTRAINT [IBG Business Entity_Code Protected Level_FK] FOREIGN KEY([Protected Level Code EN])
REFERENCES [IBG_Schema].[Code Protected Level] ([Protected Level Code EN])
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] CHECK CONSTRAINT [IBG Business Entity_Code Protected Level_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity]  WITH CHECK ADD  CONSTRAINT [IBG Business Entity_Code Sensitivity Level_FK] FOREIGN KEY([Sensitivity Level Code EN])
REFERENCES [IBG_Schema].[Code Sensitivity Level] ([Sensitivity Level Code EN])
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] CHECK CONSTRAINT [IBG Business Entity_Code Sensitivity Level_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity]  WITH CHECK ADD  CONSTRAINT [IBG Business Entity_DG Person_FK] FOREIGN KEY([Business Metadata Approved By Person Name])
REFERENCES [IBG_Schema].[DG Person] ([Person Name])
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] CHECK CONSTRAINT [IBG Business Entity_DG Person_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity]  WITH CHECK ADD  CONSTRAINT [IBG Business Entity_IBG Subject Area_FK] FOREIGN KEY([Subject Area Name EN])
REFERENCES [IBG_Schema].[IBG Subject Area] ([Subject Area Name EN])
GO

ALTER TABLE [IBG_Schema].[IBG Business Entity] CHECK CONSTRAINT [IBG Business Entity_IBG Subject Area_FK]
GO


DROP VIEW 
 [IBG_Schema].[View IBG Business Entity]
GO

CREATE view 
 [IBG_Schema].[View IBG Business Entity]
(
[Business Entity Name EN]
      ,[Subject Area Name EN]
      ,[Business Entity Name FR]
      ,[Business Entity Definition EN]
      ,[Business Entity Definition FR]
      ,[Business Metadata Status Code EN]
      ,[Business Metadata Approved By Person Name]
      ,[Business Metadata Approved Date]
      ,[Sensitivity Level Code EN]
      ,[Protected Level Code EN]
      ,[Business Entity Notes EN]
      ,[Business Entity Notes FR]
      ,[IBG Create Date Time]
)

AS

SELECT [Business Entity Name EN]
      ,[Subject Area Name EN]
      ,[Business Entity Name 2NDL]
      ,[Business Entity Definition EN]
      ,[Business Entity Definition 2NDL]
      ,[Business Metadata Status Code EN]
      ,[Business Metadata Approved By Person Name]
      ,[Business Metadata Approved Date]
      ,[Sensitivity Level Code EN]
      ,[Protected Level Code EN]
      ,[Business Entity Notes EN]
      ,[Business Entity Notes 2NDL]
      ,[IBG Create Date Time]
  FROM [IBG_Schema].[IBG Business Entity]

GO