/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[IBG Business Intelligence Object](
	[BI Object Name EN] [char](64) NOT NULL,
	[BI Object Type EN] [char](64) NOT NULL,
	[BI Accountable Business Unit Acronym EN] [char](64) NOT NULL,
	[BI Object Name 2NDL] [char](256) NOT NULL,
	[Business Metadata Status Code EN] [char](64) NOT NULL,
	[BI Application Software Nickname EN] [char](64) NOT NULL,
	[BI Hyperlink] [varchar](8000) NOT NULL,
	[BI Object Description EN] [varchar](8000) NOT NULL,
	[BI Object Description 2NDL] [varchar](8000) NOT NULL,
	[Protected Level Code EN] [char](64) NOT NULL,
	[Sensitivity Level Code EN] [char](64) NOT NULL,
	[Business Intelligence Object Notes EN] [varchar](8000) NOT NULL,
	[Business Intelligence Object Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [IBG Business Intelligence Object_PK] PRIMARY KEY CLUSTERED 
(
	[BI Object Name EN] ASC,
	[BI Object Type EN] ASC,
	[BI Accountable Business Unit Acronym EN] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [BI Object Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [BI Object Type EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [BI Accountable Business Unit Acronym EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [BI Object Name 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Metadata Status Code EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [BI Application Software Nickname EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [BI Hyperlink]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [BI Object Description EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [BI Object Description 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Protected Level Code EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Sensitivity Level Code EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Intelligence Object Notes EN]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Intelligence Object Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object]  WITH CHECK ADD  CONSTRAINT [IBG Business Intelligence Object_IBG Application Software_FK] FOREIGN KEY([BI Application Software Nickname EN])
REFERENCES [IBG_Schema].[IBG Application Software] ([Application Software Nickname EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] CHECK CONSTRAINT [IBG Business Intelligence Object_IBG Application Software_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object]  WITH CHECK ADD  CONSTRAINT [IBG Business Intelligence Object_Code BI Object Type_FK] FOREIGN KEY([BI Object Type EN])
REFERENCES [IBG_Schema].[Code BI Object Type] ([BI Object Type EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] CHECK CONSTRAINT [IBG Business Intelligence Object_Code BI Object Type_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object]  WITH CHECK ADD  CONSTRAINT [IBG Business Intelligence Object_Code Business Metadata Status_FK] FOREIGN KEY([Business Metadata Status Code EN])
REFERENCES [IBG_Schema].[Code Business Metadata Status] ([Business Metadata Status Code EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] CHECK CONSTRAINT [IBG Business Intelligence Object_Code Business Metadata Status_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object]  WITH CHECK ADD  CONSTRAINT [IBG Business Intelligence Object_DG Business Unit_FK] FOREIGN KEY([BI Accountable Business Unit Acronym EN])
REFERENCES [IBG_Schema].[DG Business Unit] ([Business Unit Acronym EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] CHECK CONSTRAINT [IBG Business Intelligence Object_DG Business Unit_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object]  WITH CHECK ADD  CONSTRAINT [IBG Business Intelligence Object_Code Protected Level_FK] FOREIGN KEY([Protected Level Code EN])
REFERENCES [IBG_Schema].[Code Protected Level] ([Protected Level Code EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] CHECK CONSTRAINT [IBG Business Intelligence Object_Code Protected Level_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object]  WITH CHECK ADD  CONSTRAINT [IBG Business Intelligence Object_Code Sensitivity Level_FK] FOREIGN KEY([Sensitivity Level Code EN])
REFERENCES [IBG_Schema].[Code Sensitivity Level] ([Sensitivity Level Code EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG Business Intelligence Object] CHECK CONSTRAINT [IBG Business Intelligence Object_Code Sensitivity Level_FK]
GO

--*************************************************************

DROP view 
 [IBG_Schema].[View IBG Business Intelligence Object]
GO

CREATE view 
 [IBG_Schema].[View IBG Business Intelligence Object]
(
       [BI Object Name EN]
      ,[BI Object Type EN]
      ,[BI Accountable Business Unit Acronym EN]
      ,[BI Object Name FR]
      ,[Business Metadata Status Code EN]
      ,[BI Application Software Nickname EN]
      ,[BI Hyperlink]
      ,[BI Object Description EN]
      ,[BI Object Description FR]
      ,[Protected Level Code EN]
      ,[Sensitivity Level Code EN]
      ,[Business Intelligence Object Notes EN]
      ,[Business Intelligence Object Notes FR]
      ,[IBG Create Date Time]
)

AS

SELECT [BI Object Name EN]
      ,[BI Object Type EN]
      ,[BI Accountable Business Unit Acronym EN]
      ,[BI Object Name 2NDL]
      ,[Business Metadata Status Code EN]
      ,[BI Application Software Nickname EN]
      ,[BI Hyperlink]
      ,[BI Object Description EN]
      ,[BI Object Description 2NDL]
      ,[Protected Level Code EN]
      ,[Sensitivity Level Code EN]
      ,[Business Intelligence Object Notes EN]
      ,[Business Intelligence Object Notes 2NDL]
      ,[IBG Create Date Time]
  FROM [IBG_Schema].[IBG Business Intelligence Object]

GO