/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[IBG ETL Program](
	[ETL Program Name] [char](64) NOT NULL,
	[ETL Application Software Nickname EN] [char](64) NOT NULL,
	[Description EN] [varchar](8000) NOT NULL,
	[Description 2NDL] [varchar](8000) NOT NULL,
	[Notes EN] [varchar](8000) NOT NULL,
	[Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [IBG ETL Program_PK] PRIMARY KEY CLUSTERED 
(
	[ETL Program Name] ASC,
	[ETL Application Software Nickname EN] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[IBG ETL Program] ADD  DEFAULT ('ZZ To Be Determined') FOR [ETL Program Name]
GO

ALTER TABLE [IBG_Schema].[IBG ETL Program] ADD  DEFAULT ('ZZ To Be Determined') FOR [ETL Application Software Nickname EN]
GO

ALTER TABLE [IBG_Schema].[IBG ETL Program] ADD  DEFAULT ('ZZ To Be Determined') FOR [Description EN]
GO

ALTER TABLE [IBG_Schema].[IBG ETL Program] ADD  DEFAULT ('ZZ To Be Determined') FOR [Description 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG ETL Program] ADD  DEFAULT ('ZZ To Be Determined') FOR [Notes EN]
GO

ALTER TABLE [IBG_Schema].[IBG ETL Program] ADD  DEFAULT ('ZZ To Be Determined') FOR [Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG ETL Program] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[IBG ETL Program]  WITH CHECK ADD  CONSTRAINT [IBG ETL Program_IBG Application Software_FK] FOREIGN KEY([ETL Application Software Nickname EN])
REFERENCES [IBG_Schema].[IBG Application Software] ([Application Software Nickname EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG ETL Program] CHECK CONSTRAINT [IBG ETL Program_IBG Application Software_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View IBG ETL Program]
GO

CREATE view 
 [IBG_Schema].[View IBG ETL Program]
(
[ETL Program Name]
      ,[ETL Application Software Nickname EN]
      ,[Description EN]
      ,[Description FR]
      ,[Notes EN]
      ,[Notes FR]
      ,[IBG Create Date Time]
)

AS

SELECT [ETL Program Name]
      ,[ETL Application Software Nickname EN]
      ,[Description EN]
      ,[Description 2NDL]
      ,[Notes EN]
      ,[Notes 2NDL]
      ,[IBG Create Date Time]
  FROM [IBG_Schema].[IBG ETL Program]

GO