/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[IBG Lineage Application Column To Application](
	[Source Application Software Nickname EN] [char](64) NOT NULL,
	[Source Column Name] [char](64) NOT NULL,
	[Source Table or View Name] [char](64) NOT NULL,
	[Source Schema Name] [char](64) NOT NULL,
	[Source Database Name] [char](64) NOT NULL,
	[Source DBMS Name] [char](64) NOT NULL,
	[ETL Program Name] [char](64) NOT NULL,
	[ETL Application Software Nickname EN] [char](64) NOT NULL,
	[Target Application Software Nickname EN] [char](64) NOT NULL,
	[Target Column Name] [char](64) NOT NULL,
	[Target Table or View Name] [char](64) NOT NULL,
	[Target Schema Name] [char](64) NOT NULL,
	[Target Database Name] [char](64) NOT NULL,
	[Target DBMS Name] [char](64) NOT NULL,
	[Lineage Application Column To Application Notes EN] [varchar](8000) NOT NULL,
	[Lineage Application Column To Application Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [IBG Lineage Application Column To Application_PK] PRIMARY KEY CLUSTERED 
(
	[Source Application Software Nickname EN] ASC,
	[Source Column Name] ASC,
	[Source Table or View Name] ASC,
	[Source Schema Name] ASC,
	[Source Database Name] ASC,
	[Source DBMS Name] ASC,
	[Target Application Software Nickname EN] ASC,
	[Target Column Name] ASC,
	[Target Table or View Name] ASC,
	[Target Schema Name] ASC,
	[Target Database Name] ASC,
	[Target DBMS Name] ASC,
	[ETL Program Name] ASC,
	[ETL Application Software Nickname EN] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Source Application Software Nickname EN]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Source Column Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Source Table or View Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Source Schema Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Source Database Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Source DBMS Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [ETL Program Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [ETL Application Software Nickname EN]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Target Application Software Nickname EN]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Target Column Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Target Table or View Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Target Schema Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Target Database Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Target DBMS Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Lineage Application Column To Application Notes EN]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Lineage Application Column To Application Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application]  WITH CHECK ADD  CONSTRAINT [IBG Lineage Application Column To Application_IBG Application Software_FK] FOREIGN KEY([Source Application Software Nickname EN])
REFERENCES [IBG_Schema].[IBG Application Software] ([Application Software Nickname EN])
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] CHECK CONSTRAINT [IBG Lineage Application Column To Application_IBG Application Software_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application]  WITH CHECK ADD  CONSTRAINT [IBG Lineage Application Column To Application_IBG Application Software_FKv1] FOREIGN KEY([Target Application Software Nickname EN])
REFERENCES [IBG_Schema].[IBG Application Software] ([Application Software Nickname EN])
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] CHECK CONSTRAINT [IBG Lineage Application Column To Application_IBG Application Software_FKv1]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application]  WITH CHECK ADD  CONSTRAINT [IBG Lineage Application Column To Application_IBG Column_FK] FOREIGN KEY([Source Column Name], [Source Table or View Name], [Source Schema Name], [Source Database Name], [Source DBMS Name])
REFERENCES [IBG_Schema].[IBG Column] ([Column Name], [Table or View Name], [Schema Name], [Database Name], [DBMS Name])
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] CHECK CONSTRAINT [IBG Lineage Application Column To Application_IBG Column_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application]  WITH CHECK ADD  CONSTRAINT [IBG Lineage Application Column To Application_IBG Column_FKv1] FOREIGN KEY([Target Column Name], [Target Table or View Name], [Target Schema Name], [Target Database Name], [Target DBMS Name])
REFERENCES [IBG_Schema].[IBG Column] ([Column Name], [Table or View Name], [Schema Name], [Database Name], [DBMS Name])
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] CHECK CONSTRAINT [IBG Lineage Application Column To Application_IBG Column_FKv1]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application]  WITH CHECK ADD  CONSTRAINT [IBG Lineage Application Column To Application_IBG ETL Program_FK] FOREIGN KEY([ETL Program Name], [ETL Application Software Nickname EN])
REFERENCES [IBG_Schema].[IBG ETL Program] ([ETL Program Name], [ETL Application Software Nickname EN])
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To Application] CHECK CONSTRAINT [IBG Lineage Application Column To Application_IBG ETL Program_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View IBG Lineage Application Column To Application]
GO

CREATE view 
 [IBG_Schema].[View IBG Lineage Application Column To Application]
(
	[Source Application Software Nickname EN],
	[Source Column Name],
	[Source Table or View Name],
	[Source Schema Name],
	[Source Database Name],
	[Source DBMS Name],
	[ETL Program Name],
	[ETL Application Software Nickname EN],
	[Target Application Software Nickname EN],
	[Target Column Name],
	[Target Table or View Name],
	[Target Schema Name],
	[Target Database Name],
	[Target DBMS Name],
	[Lineage Application Column To Application Notes EN],
	[Lineage Application Column To Application Notes FR],
	[IBG Create Date Time]
)

AS

SELECT 
	[Source Application Software Nickname EN],
	[Source Column Name],
	[Source Table or View Name],
	[Source Schema Name],
	[Source Database Name],
	[Source DBMS Name],
	[ETL Program Name],
	[ETL Application Software Nickname EN],
	[Target Application Software Nickname EN],
	[Target Column Name],
	[Target Table or View Name],
	[Target Schema Name],
	[Target Database Name],
	[Target DBMS Name],
	[Lineage Application Column To Application Notes EN],
	[Lineage Application Column To Application Notes 2NDL],
	[IBG Create Date Time]
  FROM [IBG_Schema].[IBG Lineage Application Column To Application]

GO
