/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object](
	[Source Application Software Nickname EN] [char](64) NOT NULL,
	[Source Column Name] [char](64) NOT NULL,
	[Source Table or View Name] [char](64) NOT NULL,
	[Source Schema Name] [char](64) NOT NULL,
	[Source Database Name] [char](64) NOT NULL,
	[Source DBMS Name] [char](64) NOT NULL,
	[ETL Program Name] [char](64) NOT NULL,
	[ETL Application Software Nickname EN] [char](64) NOT NULL,
	[Target BI Object Name EN] [char](64) NOT NULL,
	[Target BI Object Type EN] [char](64) NOT NULL,
	[Target BI Accountable Business Unit Acronym EN] [char](64) NOT NULL,
	[Lineage Application Column To BI Object Notes EN] [varchar](8000) NOT NULL,
	[Lineage Application Column To BI Object Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [IBG Lineage Application Column To BI Object_PK] PRIMARY KEY CLUSTERED 
(
	[ETL Program Name] ASC,
	[ETL Application Software Nickname EN] ASC,
	[Target BI Object Name EN] ASC,
	[Target BI Object Type EN] ASC,
	[Target BI Accountable Business Unit Acronym EN] ASC,
	[Source Application Software Nickname EN] ASC,
	[Source Column Name] ASC,
	[Source Table or View Name] ASC,
	[Source Schema Name] ASC,
	[Source Database Name] ASC,
	[Source DBMS Name] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Source Application Software Nickname EN]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Source Column Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Source Table or View Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Source Schema Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Source Database Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Source DBMS Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [ETL Program Name]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [ETL Application Software Nickname EN]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Target BI Object Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Target BI Object Type EN]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Target BI Accountable Business Unit Acronym EN]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Lineage Application Column To BI Object Notes EN]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Lineage Application Column To BI Object Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object]  WITH CHECK ADD  CONSTRAINT [IBG Lineage Application Column To BI Object_IBG Application Software_FK] FOREIGN KEY([Source Application Software Nickname EN])
REFERENCES [IBG_Schema].[IBG Application Software] ([Application Software Nickname EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] CHECK CONSTRAINT [IBG Lineage Application Column To BI Object_IBG Application Software_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object]  WITH CHECK ADD  CONSTRAINT [IBG Lineage Application Column To BI Object_IBG Business Intelligence Object_FK] FOREIGN KEY([Target BI Object Name EN], [Target BI Object Type EN], [Target BI Accountable Business Unit Acronym EN])
REFERENCES [IBG_Schema].[IBG Business Intelligence Object] ([BI Object Name EN], [BI Object Type EN], [BI Accountable Business Unit Acronym EN])
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] CHECK CONSTRAINT [IBG Lineage Application Column To BI Object_IBG Business Intelligence Object_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object]  WITH CHECK ADD  CONSTRAINT [IBG Lineage Application Column To BI Object_IBG Column_FK] FOREIGN KEY([Source Column Name], [Source Table or View Name], [Source Schema Name], [Source Database Name], [Source DBMS Name])
REFERENCES [IBG_Schema].[IBG Column] ([Column Name], [Table or View Name], [Schema Name], [Database Name], [DBMS Name])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] CHECK CONSTRAINT [IBG Lineage Application Column To BI Object_IBG Column_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object]  WITH CHECK ADD  CONSTRAINT [IBG Lineage Application Column To BI Object_IBG ETL Program_FK] FOREIGN KEY([ETL Program Name], [ETL Application Software Nickname EN])
REFERENCES [IBG_Schema].[IBG ETL Program] ([ETL Program Name], [ETL Application Software Nickname EN])
GO

ALTER TABLE [IBG_Schema].[IBG Lineage Application Column To BI Object] CHECK CONSTRAINT [IBG Lineage Application Column To BI Object_IBG ETL Program_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View IBG Lineage Application Column To BI Object]
GO

CREATE view 
 [IBG_Schema].[View IBG Lineage Application Column To BI Object]
(
	[Source Application Software Nickname EN],
	[Source Column Name],
	[Source Table or View Name],
	[Source Schema Name],
	[Source Database Name],
	[Source DBMS Name],
	[ETL Program Name],
	[ETL Application Software Nickname EN],
	[Target BI Object Name EN],
	[Target BI Object Type EN],
	[Target BI Accountable Business Unit Acronym EN],
	[Lineage Application Column To BI Object Notes EN],
	[Lineage Application Column To BI Object Notes FR],
	[IBG Create Date Time]
)

AS

SELECT 
	[Source Application Software Nickname EN],
	[Source Column Name],
	[Source Table or View Name],
	[Source Schema Name],
	[Source Database Name],
	[Source DBMS Name],
	[ETL Program Name],
	[ETL Application Software Nickname EN],
	[Target BI Object Name EN],
	[Target BI Object Type EN],
	[Target BI Accountable Business Unit Acronym EN],
	[Lineage Application Column To BI Object Notes EN],
	[Lineage Application Column To BI Object Notes 2NDL],
	[IBG Create Date Time]
  FROM [IBG_Schema].[IBG Lineage Application Column To BI Object]

GO