/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[IBG Subject Area](
	[Subject Area Name EN] [char](64) NOT NULL,
	[Subject Area Name 2NDL] [char](64) NOT NULL,
	[Subject Area Definition EN] [varchar](8000) NOT NULL,
	[Subject Area Definition 2NDL] [varchar](8000) NOT NULL,
	[Business Metadata Status Code EN] [char](64) NOT NULL,
	[Business Metadata Approved By Person Name] [char](128) NOT NULL,
	[Business Metadata Approved Date] [date] NOT NULL,
	[Subject Area Notes EN] [varchar](8000) NOT NULL,
	[Subject Area Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [IBG Subject Area_PK] PRIMARY KEY CLUSTERED 
(
	[Subject Area Name EN] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[IBG Subject Area] ADD  DEFAULT ('ZZ To Be Determined') FOR [Subject Area Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG Subject Area] ADD  DEFAULT ('ZZ To Be Determined') FOR [Subject Area Name 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Subject Area] ADD  DEFAULT ('ZZ To Be Determined') FOR [Subject Area Definition EN]
GO

ALTER TABLE [IBG_Schema].[IBG Subject Area] ADD  DEFAULT ('ZZ To Be Determined') FOR [Subject Area Definition 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Subject Area] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Metadata Status Code EN]
GO

ALTER TABLE [IBG_Schema].[IBG Subject Area] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Metadata Approved By Person Name]
GO

ALTER TABLE [IBG_Schema].[IBG Subject Area] ADD  DEFAULT ('9999-12-31') FOR [Business Metadata Approved Date]
GO

ALTER TABLE [IBG_Schema].[IBG Subject Area] ADD  DEFAULT ('ZZ To Be Determined') FOR [Subject Area Notes EN]
GO

ALTER TABLE [IBG_Schema].[IBG Subject Area] ADD  DEFAULT ('ZZ To Be Determined') FOR [Subject Area Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Subject Area] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[IBG Subject Area]  WITH CHECK ADD  CONSTRAINT [IBG Subject Area_Code Business Metadata Status_FK] FOREIGN KEY([Business Metadata Status Code EN])
REFERENCES [IBG_Schema].[Code Business Metadata Status] ([Business Metadata Status Code EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG Subject Area] CHECK CONSTRAINT [IBG Subject Area_Code Business Metadata Status_FK]
GO

ALTER TABLE [IBG_Schema].[IBG Subject Area]  WITH CHECK ADD  CONSTRAINT [IBG Subject Area_DG Person_FK] FOREIGN KEY([Business Metadata Approved By Person Name])
REFERENCES [IBG_Schema].[DG Person] ([Person Name])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG Subject Area] CHECK CONSTRAINT [IBG Subject Area_DG Person_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View IBG Subject Area]
GO

CREATE view 
 [IBG_Schema].[View IBG Subject Area]
(
       [Subject Area Name EN]
      ,[Subject Area Name FR]
      ,[Subject Area Definition EN]
      ,[Subject Area Definition FR]
      ,[Business Metadata Status Code EN]
      ,[Business Metadata Approved By Person Name] 
      ,[Business Metadata Approved Date]
      ,[Subject Area Notes EN]
      ,[Subject Area Notes FR]
      ,[IBG Create Date Time]
)

AS

SELECT [Subject Area Name EN]
      ,[Subject Area Name 2NDL]
      ,[Subject Area Definition EN]
      ,[Subject Area Definition 2NDL]
      ,[Business Metadata Status Code EN]
      ,[Business Metadata Approved By Person Name] 
      ,[Business Metadata Approved Date]
      ,[Subject Area Notes EN]
      ,[Subject Area Notes 2NDL]
      ,[IBG Create Date Time]
  FROM [IBG_Schema].[IBG Subject Area]

GO