/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[IBG Table or View](
	[Table or View Name] [char](64) NOT NULL,
	[Schema Name] [char](64) NOT NULL,
	[Database Name] [char](64) NOT NULL,
	[DBMS Name] [char](64) NOT NULL,
	[Notes EN] [varchar](8000) NOT NULL,
	[Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [IBG Table or View_PK] PRIMARY KEY CLUSTERED 
(
	[Table or View Name] ASC,
	[Schema Name] ASC,
	[Database Name] ASC,
	[DBMS Name] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[IBG Table or View] ADD  DEFAULT ('ZZ To Be Determined') FOR [Table or View Name]
GO

ALTER TABLE [IBG_Schema].[IBG Table or View] ADD  DEFAULT ('ZZ To Be Determined') FOR [Schema Name]
GO

ALTER TABLE [IBG_Schema].[IBG Table or View] ADD  DEFAULT ('ZZ To Be Determined') FOR [Database Name]
GO

ALTER TABLE [IBG_Schema].[IBG Table or View] ADD  DEFAULT ('ZZ To Be Determined') FOR [DBMS Name]
GO

ALTER TABLE [IBG_Schema].[IBG Table or View] ADD  DEFAULT ('ZZ To Be Determined') FOR [Notes EN]
GO

ALTER TABLE [IBG_Schema].[IBG Table or View] ADD  DEFAULT ('ZZ To Be Determined') FOR [Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG Table or View] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[IBG Table or View]  WITH CHECK ADD  CONSTRAINT [IBG Table or View_IBG Schema_FK] FOREIGN KEY([Schema Name], [Database Name], [DBMS Name])
REFERENCES [IBG_Schema].[IBG Schema] ([Schema Name], [Database Name], [DBMS Name])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG Table or View] CHECK CONSTRAINT [IBG Table or View_IBG Schema_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View IBG Table or View]
GO

CREATE view 
 [IBG_Schema].[View IBG Table or View]
(
[Table or View Name]
      ,[Schema Name]
      ,[Database Name]
      ,[DBMS Name]
      ,[Notes EN]
      ,[Notes FR]
      ,[IBG Create Date Time]
)

AS

SELECT [Table or View Name]
      ,[Schema Name]
      ,[Database Name]
      ,[DBMS Name]
      ,[Notes EN]
      ,[Notes 2NDL]
      ,[IBG Create Date Time]
  FROM [IBG_Schema].[IBG Table or View]

GO