/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[IBG XREF BA Column And Application](
	[Business Attribute Name EN] [char](64) NOT NULL,
	[Business Entity Name EN] [char](64) NOT NULL,
	[Subject Area Name EN] [char](64) NOT NULL,
	[Column Name] [char](64) NOT NULL,
	[Table or View Name] [char](64) NOT NULL,
	[Schema Name] [char](64) NOT NULL,
	[Database Name] [char](64) NOT NULL,
	[DBMS Name] [char](64) NOT NULL,
	[Application Software Nickname EN] [char](64) NOT NULL,
	[Application SW Window Name EN] [char](64) NOT NULL,
	[Application SW Field Name EN] [char](64) NOT NULL,
	[System Of Record Or Reference Code EN] [char](64) NOT NULL,
	[Business Attribute Column Application Notes EN] [varchar](8000) NOT NULL,
	[Business Attribute Column Application Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [IBG XREF BA Column And Application_PK] PRIMARY KEY CLUSTERED 
(
	[Business Attribute Name EN] ASC,
	[Business Entity Name EN] ASC,
	[Subject Area Name EN] ASC,
	[Column Name] ASC,
	[Table or View Name] ASC,
	[Schema Name] ASC,
	[Database Name] ASC,
	[DBMS Name] ASC,
	[Application Software Nickname EN] ASC,
	[Application SW Window Name EN] ASC,
	[Application SW Field Name EN] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Attribute Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Entity Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Subject Area Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Column Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Table or View Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Schema Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Database Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [DBMS Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Application Software Nickname EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Application SW Window Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Application SW Field Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [System Of Record Or Reference Code EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Attribute Column Application Notes EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Attribute Column Application Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application]  WITH CHECK ADD  CONSTRAINT [IBG XREF BA Column And Application_Code System Of Record Or Reference_FK] FOREIGN KEY([System Of Record Or Reference Code EN])
REFERENCES [IBG_Schema].[Code System Of Record Or Reference] ([System Of Record Or Reference Code EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] CHECK CONSTRAINT [IBG XREF BA Column And Application_Code System Of Record Or Reference_FK]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application]  WITH CHECK ADD  CONSTRAINT [IBG XREF BA Column And Application_IBG Application Software Field_FK] FOREIGN KEY([Application SW Window Name EN], [Application SW Field Name EN], [Application Software Nickname EN])
REFERENCES [IBG_Schema].[IBG Application Software Field] ([Application SW Window Name EN], [Application SW Field Name EN], [Application Software Nickname EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] CHECK CONSTRAINT [IBG XREF BA Column And Application_IBG Application Software Field_FK]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application]  WITH CHECK ADD  CONSTRAINT [IBG XREF BA Column And Application_IBG XREF BA And Column_FK] FOREIGN KEY([Business Entity Name EN], [Subject Area Name EN], [Business Attribute Name EN], [Column Name], [Table or View Name], [Schema Name], [Database Name], [DBMS Name])
REFERENCES [IBG_Schema].[IBG XREF BA And Column] ([Business Entity Name EN], [Subject Area Name EN], [Business Attribute Name EN], [Column Name], [Table or View Name], [Schema Name], [Database Name], [DBMS Name])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Column And Application] CHECK CONSTRAINT [IBG XREF BA Column And Application_IBG XREF BA And Column_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View IBG XREF BA Column And Application]
GO

CREATE view 
 [IBG_Schema].[View IBG XREF BA Column And Application]
(
	[Business Attribute Name EN],
	[Business Entity Name EN],
	[Subject Area Name EN],
	[Column Name],
	[Table or View Name],
	[Schema Name],
	[Database Name],
	[DBMS Name],
	[Application Software Nickname EN],
	[Application SW Window Name EN],
	[Application SW Field Name EN],
	[System Of Record Or Reference Code EN],
	[Business Attribute Column Application Notes EN],
	[Business Attribute Column Application Notes FR],
	[IBG Create Date Time]
)

AS

SELECT 
	[Business Attribute Name EN],
	[Business Entity Name EN],
	[Subject Area Name EN],
	[Column Name],
	[Table or View Name],
	[Schema Name],
	[Database Name],
	[DBMS Name],
	[Application Software Nickname EN],
	[Application SW Window Name EN],
	[Application SW Field Name EN],
	[System Of Record Or Reference Code EN],
	[Business Attribute Column Application Notes EN],
	[Business Attribute Column Application Notes 2NDL],
	[IBG Create Date Time]
  FROM [IBG_Schema].[IBG XREF BA Column And Application]

GO