/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application](
	[Data Issue ID] [int] NOT NULL,
	[Business Attribute Name EN] [char](64) NOT NULL,
	[Business Entity Name EN] [char](64) NOT NULL,
	[Subject Area Name EN] [char](64) NOT NULL,
	[Column Name] [char](64) NOT NULL,
	[Table or View Name] [char](64) NOT NULL,
	[Schema Name] [char](64) NOT NULL,
	[Database Name] [char](64) NOT NULL,
	[DBMS Name] [char](64) NOT NULL,
	[Application Software Nickname EN] [char](64) NOT NULL,
	[Application SW Window Name EN] [char](64) NOT NULL,
	[Application SW Field Name EN] [char](64) NOT NULL,
	[Data Issue BA Column And Application Notes EN] [varchar](8000) NOT NULL,
	[Data Issue BA Column And Application Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [IBG XREF BA Data Issue And Application_PK] PRIMARY KEY CLUSTERED 
(
	[Data Issue ID] ASC,
	[Business Attribute Name EN] ASC,
	[Business Entity Name EN] ASC,
	[Subject Area Name EN] ASC,
	[Column Name] ASC,
	[Table or View Name] ASC,
	[Schema Name] ASC,
	[Database Name] ASC,
	[DBMS Name] ASC,
	[Application Software Nickname EN] ASC,
	[Application SW Window Name EN] ASC,
	[Application SW Field Name EN] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] ADD  DEFAULT ((0)) FOR [Data Issue ID]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Attribute Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Entity Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Subject Area Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Column Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Table or View Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Schema Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Database Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [DBMS Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Application Software Nickname EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Application SW Window Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Application SW Field Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue BA Column And Application Notes EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue BA Column And Application Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application]  WITH CHECK ADD  CONSTRAINT [IBG XREF BA Data Issue And Application_DG Data Issue Register_FK] FOREIGN KEY([Data Issue ID])
REFERENCES [IBG_Schema].[DG Data Issue Register] ([Data Issue ID])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] CHECK CONSTRAINT [IBG XREF BA Data Issue And Application_DG Data Issue Register_FK]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application]  WITH CHECK ADD  CONSTRAINT [IBG XREF BA Data Issue And Application_IBG XREF BA Column And Application_FK] FOREIGN KEY([Business Attribute Name EN], [Business Entity Name EN], [Subject Area Name EN], [Column Name], [Table or View Name], [Schema Name], [Database Name], [DBMS Name], [Application Software Nickname EN], [Application SW Window Name EN], [Application SW Field Name EN])
REFERENCES [IBG_Schema].[IBG XREF BA Column And Application] ([Business Attribute Name EN], [Business Entity Name EN], [Subject Area Name EN], [Column Name], [Table or View Name], [Schema Name], [Database Name], [DBMS Name], [Application Software Nickname EN], [Application SW Window Name EN], [Application SW Field Name EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And Application] CHECK CONSTRAINT [IBG XREF BA Data Issue And Application_IBG XREF BA Column And Application_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View IBG XREF BA Data Issue And Application]
GO

CREATE view 
 [IBG_Schema].[View IBG XREF BA Data Issue And Application]
(
	[Data Issue ID],
	[Business Attribute Name EN],
	[Business Entity Name EN],
	[Subject Area Name EN],
	[Column Name],
	[Table or View Name],
	[Schema Name],
	[Database Name],
	[DBMS Name],
	[Application Software Nickname EN],
	[Application SW Window Name EN],
	[Application SW Field Name EN],
	[Data Issue BA Column And Application Notes EN],
	[Data Issue BA Column And Application Notes FR],
	[IBG Create Date Time]
)

AS

SELECT 
	[Data Issue ID],
	[Business Attribute Name EN],
	[Business Entity Name EN],
	[Subject Area Name EN],
	[Column Name],
	[Table or View Name],
	[Schema Name],
	[Database Name],
	[DBMS Name],
	[Application Software Nickname EN],
	[Application SW Window Name EN],
	[Application SW Field Name EN],
	[Data Issue BA Column And Application Notes EN],
	[Data Issue BA Column And Application Notes 2NDL],
	[IBG Create Date Time]
  FROM [IBG_Schema].[IBG XREF BA Data Issue And Application]

GO