/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object](
	[Data Issue ID] [int] NOT NULL,
	[Business Attribute Name EN] [char](64) NOT NULL,
	[Business Entity Name EN] [char](64) NOT NULL,
	[Subject Area Name EN] [char](64) NOT NULL,
	[Column Name] [char](64) NOT NULL,
	[Table or View Name] [char](64) NOT NULL,
	[Schema Name] [char](64) NOT NULL,
	[Database Name] [char](64) NOT NULL,
	[DBMS Name] [char](64) NOT NULL,
	[BI Object Name EN] [char](64) NOT NULL,
	[BI Object Type EN] [char](64) NOT NULL,
	[BI Accountable Business Unit Acronym EN] [char](64) NOT NULL,
	[Data Issue BA Column And BI Object Notes EN] [varchar](8000) NOT NULL,
	[Data Issue BA Column And BI Object Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [IBG XREF BA Data Issue And BI Object_PK] PRIMARY KEY CLUSTERED 
(
	[Data Issue ID] ASC,
	[Business Entity Name EN] ASC,
	[Subject Area Name EN] ASC,
	[Business Attribute Name EN] ASC,
	[Column Name] ASC,
	[Table or View Name] ASC,
	[Schema Name] ASC,
	[Database Name] ASC,
	[DBMS Name] ASC,
	[BI Object Name EN] ASC,
	[BI Object Type EN] ASC,
	[BI Accountable Business Unit Acronym EN] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] ADD  DEFAULT ((0)) FOR [Data Issue ID]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Attribute Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Entity Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Subject Area Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Column Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Table or View Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Schema Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Database Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [DBMS Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [BI Object Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [BI Object Type EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [BI Accountable Business Unit Acronym EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue BA Column And BI Object Notes EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] ADD  DEFAULT ('ZZ To Be Determined') FOR [Data Issue BA Column And BI Object Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object]  WITH CHECK ADD  CONSTRAINT [IBG XREF BA Data Issue And BI Object_DG Data Issue Register_FK] FOREIGN KEY([Data Issue ID])
REFERENCES [IBG_Schema].[DG Data Issue Register] ([Data Issue ID])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] CHECK CONSTRAINT [IBG XREF BA Data Issue And BI Object_DG Data Issue Register_FK]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object]  WITH CHECK ADD  CONSTRAINT [IBG XREF BA Data Issue And BI Object_IBG XREF BA Column And BI Object_FK] FOREIGN KEY([Business Entity Name EN], [Subject Area Name EN], [Business Attribute Name EN], [Column Name], [Table or View Name], [Schema Name], [Database Name], [DBMS Name], [BI Object Name EN], [BI Object Type EN], [BI Accountable Business Unit Acronym EN])
REFERENCES [IBG_Schema].[IBG XREF BA Column And BI Object] ([Business Entity Name EN], [Subject Area Name EN], [Business Attribute Name EN], [Column Name], [Table or View Name], [Schema Name], [Database Name], [DBMS Name], [BI Object Name EN], [BI Object Type EN], [BI Accountable Business Unit Acronym EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG XREF BA Data Issue And BI Object] CHECK CONSTRAINT [IBG XREF BA Data Issue And BI Object_IBG XREF BA Column And BI Object_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View IBG XREF BA Data Issue And BI Object]
GO

CREATE view 
 [IBG_Schema].[View IBG XREF BA Data Issue And BI Object]
(
	[Data Issue ID],
	[Business Attribute Name EN],
	[Business Entity Name EN],
	[Subject Area Name EN],
	[Column Name],
	[Table or View Name],
	[Schema Name],
	[Database Name],
	[DBMS Name],
	[BI Object Name EN],
	[BI Object Type EN],
	[BI Accountable Business Unit Acronym EN],
	[Data Issue BA Column And BI Object Notes EN],
	[Data Issue BA Column And BI Object Notes FR],
	[IBG Create Date Time]
)

AS
 
SELECT	
	[Data Issue ID],
	[Business Attribute Name EN],
	[Business Entity Name EN],
	[Subject Area Name EN],
	[Column Name],
	[Table or View Name],
	[Schema Name],
	[Database Name],
	[DBMS Name],
	[BI Object Name EN],
	[BI Object Type EN],
	[BI Accountable Business Unit Acronym EN],
	[Data Issue BA Column And BI Object Notes EN],
	[Data Issue BA Column And BI Object Notes 2NDL],
	[IBG Create Date Time]
  FROM [IBG_Schema].[IBG XREF BA Data Issue And BI Object]

GO