/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/


SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE TABLE [IBG_Schema].[IBG XREF BE And Table Or View](
	[Business Entity Name EN] [char](64) NOT NULL,
	[Subject Area Name EN] [char](64) NOT NULL,
	[Table or View Name] [char](64) NOT NULL,
	[Schema Name] [char](64) NOT NULL,
	[Database Name] [char](64) NOT NULL,
	[DBMS Name] [char](64) NOT NULL,
	[Business Entity And Table View Notes EN] [varchar](8000) NOT NULL,
	[Business Entity And Table View Notes 2NDL] [varchar](8000) NOT NULL,
	[IBG Create Date Time] [datetime] NOT NULL,
 CONSTRAINT [IBG XREF BE And Table Or View_PK] PRIMARY KEY CLUSTERED 
(
	[Table or View Name] ASC,
	[Schema Name] ASC,
	[Database Name] ASC,
	[DBMS Name] ASC,
	[Business Entity Name EN] ASC,
	[Subject Area Name EN] ASC
)WITH (PAD_INDEX = OFF, STATISTICS_NORECOMPUTE = OFF, IGNORE_DUP_KEY = OFF, ALLOW_ROW_LOCKS = ON, ALLOW_PAGE_LOCKS = ON, OPTIMIZE_FOR_SEQUENTIAL_KEY = OFF) ON [PRIMARY]
) ON [PRIMARY]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BE And Table Or View] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Entity Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BE And Table Or View] ADD  DEFAULT ('ZZ To Be Determined') FOR [Subject Area Name EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BE And Table Or View] ADD  DEFAULT ('ZZ To Be Determined') FOR [Table or View Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BE And Table Or View] ADD  DEFAULT ('ZZ To Be Determined') FOR [Schema Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BE And Table Or View] ADD  DEFAULT ('ZZ To Be Determined') FOR [Database Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BE And Table Or View] ADD  DEFAULT ('ZZ To Be Determined') FOR [DBMS Name]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BE And Table Or View] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Entity And Table View Notes EN]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BE And Table Or View] ADD  DEFAULT ('ZZ To Be Determined') FOR [Business Entity And Table View Notes 2NDL]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BE And Table Or View] ADD  DEFAULT (getdate()) FOR [IBG Create Date Time]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BE And Table Or View]  WITH CHECK ADD  CONSTRAINT [IBG XREF BE And Table Or View_IBG Business Entity_FK] FOREIGN KEY([Business Entity Name EN], [Subject Area Name EN])
REFERENCES [IBG_Schema].[IBG Business Entity] ([Business Entity Name EN], [Subject Area Name EN])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG XREF BE And Table Or View] CHECK CONSTRAINT [IBG XREF BE And Table Or View_IBG Business Entity_FK]
GO

ALTER TABLE [IBG_Schema].[IBG XREF BE And Table Or View]  WITH CHECK ADD  CONSTRAINT [IBG XREF BE And Table Or View_IBG Table or View_FK] FOREIGN KEY([Table or View Name], [Schema Name], [Database Name], [DBMS Name])
REFERENCES [IBG_Schema].[IBG Table or View] ([Table or View Name], [Schema Name], [Database Name], [DBMS Name])
ON UPDATE CASCADE
GO

ALTER TABLE [IBG_Schema].[IBG XREF BE And Table Or View] CHECK CONSTRAINT [IBG XREF BE And Table Or View_IBG Table or View_FK]
GO

--*************************************************************

DROP VIEW 
 [IBG_Schema].[View IBG XREF BE And Table Or View]
GO

CREATE view 
 [IBG_Schema].[View IBG XREF BE And Table Or View]
(
[Business Entity Name EN]
      ,[Subject Area Name EN]
      ,[Table or View Name]
      ,[Schema Name]
      ,[Database Name]
      ,[DBMS Name]
      ,[Business Entity And Table View Notes EN]
      ,[Business Entity And Table View Notes FR]
      ,[IBG Create Date Time]
)

AS

SELECT [Business Entity Name EN]
      ,[Subject Area Name EN]
      ,[Table or View Name]
      ,[Schema Name]
      ,[Database Name]
      ,[DBMS Name]
      ,[Business Entity And Table View Notes EN]
      ,[Business Entity And Table View Notes 2NDL]
      ,[IBG Create Date Time]
  FROM [IBG_Schema].[IBG XREF BE And Table Or View]

GO