/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

DROP view 
 [IBG_Schema].[View - PB - Data Issue Snapshot]
GO

CREATE view 
 [IBG_Schema].[View - PB - Data Issue Snapshot]
AS
SELECT 
       [Register].[Data Issue ID]
      ,[History].[Data Issue Status History Date]               as [Data Issue Current Status Date]
      ,'==>'                                                    as [English Language Information Follows]
      ,[Register].[Data Issue Title EN]
      ,[Code Data Issue Status].[Data Issue Status Code EN]
      ,[Code Data Issue Category].[Data Issue Category Code EN]
      ,[Code Data Issue Severity].[Data Issue Severity Code EN]
      ,[Register].[Data Issue Priority Code]
      ,[Code Data Issue Impact].[Data Issue Impact Code EN]
      ,[Business Unit].[Business Unit Acronym EN]               as [Impacted Business Unit Acronym EN]
      ,[Business Unit].[Business Unit Full Name EN]             as [Impacted Business Unit Full Name EN]
      ,'==>'                                                    as [Second Language Information Begins]
      ,[Register].[Data Issue Title FR]
      ,[Code Data Issue Status].[Data Issue Status Code FR]
      ,[Code Data Issue Category].[Data Issue Category Code FR]
      ,[Code Data Issue Severity].[Data Issue Severity Code FR]
      ,[Register].[Data Issue Priority Code]                    as [Data Issue Priority Code FR]
      ,[Code Data Issue Impact].[Data Issue Impact Code FR]
      ,[Business Unit].[Business Unit Acronym FR]               as [Impacted Business Unit Acronym FR]
      ,[Business Unit].[Business Unit Full Name FR]             as [Impacted Business Unit Full Name FR]
      , SYSDATETIME()                                           as [IBG Publish Date]

  FROM [IBG_Schema].[View DG Data Issue Register]           [Register]
      ,[IBG_Schema].[View DG Data Issue Status History]     [History]
      ,[IBG_Schema].[View DG Data Issue And Business Unit]  [BU Impact]
      ,[IBG_Schema].[View DG Business Unit]                 [Business Unit]
      ,[IBG_Schema].[View Code Data Issue Status]           [Code Data Issue Status]
      ,[IBG_Schema].[View Code Data Issue Category]         [Code Data Issue Category]
      ,[IBG_Schema].[View Code Data Issue Severity]         [Code Data Issue Severity]
      ,[IBG_Schema].[View Code Data Issue Impact]           [Code Data Issue Impact]

WHERE
       [Register].[Data Issue ID] = [History].[Data Issue ID]
AND
       [Register].[Data Issue ID] = [BU Impact].[Data Issue ID]
AND
       [BU Impact].[Business Unit Acronym EN] = [Business Unit].[Business Unit Acronym EN]

AND
       [History].[Data Issue Status Code EN]    = [Code Data Issue Status].[Data Issue Status Code EN]
AND
       [Register].[Data Issue Category Code EN] = [Code Data Issue Category].[Data Issue Category Code EN]
AND
       [Register].[Data Issue Severity Code EN] = [Code Data Issue Severity].[Data Issue Severity Code EN]
AND
       [BU Impact].[Data Issue Impact Code EN]  = [Code Data Issue Impact].[Data Issue Impact Code EN]

AND
      [History].[Data Issue Status History Date] = 
     (SELECT MAX([Data Issue Status History Date])
       FROM [IBG_Schema].[View DG Data Issue Status History] [History Max]
      WHERE [History Max].[Data Issue ID] = [Register].[Data Issue ID]
     )

GO