/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

DROP view 
 [IBG_Schema].[View - PB - Lineage Application To Application]
GO

CREATE view 
 [IBG_Schema].[View - PB - Lineage Application To Application]
AS

SELECT 
       [LACA].[Source Application Software Nickname EN]
      ,[LACA].[Source Column Name]
      ,[LACA].[Source Table or View Name]
      ,[LACA].[Source Schema Name]
      ,[LACA].[Source Database Name]
      ,[LACA].[Source DBMS Name]
      ,[Code_SORR_Source].[System Of Record Or Reference Code EN] as [Source System Of Record Or Reference Code EN]
      ,[Code_SORR_Source].[System Of Record Or Reference Code FR] as [Source System Of Record Or Reference Code FR]
      ,[LACA].[Target Application Software Nickname EN]
      ,[LACA].[Target Column Name]
      ,[LACA].[Target Table or View Name]
      ,[LACA].[Target Schema Name]
      ,[LACA].[Target Database Name]
      ,[LACA].[Target DBMS Name]
      ,[Code_SORR_Target].[System Of Record Or Reference Code EN] as [Target System Of Record Or Reference Code EN]
      ,[Code_SORR_Target].[System Of Record Or Reference Code FR] as [Target System Of Record Or Reference Code FR]
      ,[LACA].[ETL Program Name]
      ,[LACA].[ETL Application Software Nickname EN]
      ,[LACA].[Lineage Application Column To Application Notes EN]
      ,[LACA].[Lineage Application Column To Application Notes FR]
      ,SYSDATETIME() AS [IBG Publish Date]
  FROM [IBG_Schema].[View IBG Lineage Application Column To Application]	as [LACA]
      ,[IBG_Schema].[View IBG XREF BA Column And Application]          	as [XREF_BACA_Source]
      ,[IBG_Schema].[View IBG XREF BA Column And Application]          	as [XREF_BACA_Target]
      ,[IBG_Schema].[View Code System Of Record Or Reference]          	as [Code_SORR_Source]
      ,[IBG_Schema].[View Code System Of Record Or Reference]          	as [Code_SORR_Target]

WHERE
       [LACA].[Source Application Software Nickname EN]	= [XREF_BACA_Source].[Application Software Nickname EN]
  AND  [LACA].[Source Column Name] 			= [XREF_BACA_Source].[Column Name]
  AND  [LACA].[Source Table or View Name]		= [XREF_BACA_Source].[Table or View Name]
  AND  [LACA].[Source Schema Name]			= [XREF_BACA_Source].[Schema Name]
  AND  [LACA].[Source Database Name]			= [XREF_BACA_Source].[Database Name]
  AND  [LACA].[Source DBMS Name]			= [XREF_BACA_Source].[DBMS Name]

  AND  [XREF_BACA_Source].[System Of Record Or Reference Code EN]	= [Code_SORR_Source].[System Of Record Or Reference Code EN]

  AND  [LACA].[Target Application Software Nickname EN]	= [XREF_BACA_Target].[Application Software Nickname EN]
  AND  [LACA].[Target Column Name] 			= [XREF_BACA_Target].[Column Name]
  AND  [LACA].[Target Table or View Name]		= [XREF_BACA_Target].[Table or View Name]
  AND  [LACA].[Target Schema Name]			= [XREF_BACA_Target].[Schema Name]
  AND  [LACA].[Target Database Name]			= [XREF_BACA_Target].[Database Name]
  AND  [LACA].[Target DBMS Name]			= [XREF_BACA_Target].[DBMS Name]

  AND  [XREF_BACA_Target].[System Of Record Or Reference Code EN]	= [Code_SORR_Target].[System Of Record Or Reference Code EN]

Go
