/*******************************************************************/
/* Use the appropriate database to load the IBG data model content */
/* When this SQL file is run as a standalone statement             */
--USE [IBG_Demo_DB]
--GO
--USE [IBG_DB]
--GO
/*                                                                 */
/*******************************************************************/

/*******************************************************************/
/* Use the SQLCMDDBNAME variable as set by the calling SQLCMD      */
/* To set the database                                             */
USE $(SQLCMDDBNAME)
GO
/*                                                                 */
/*******************************************************************/

SET ANSI_NULLS ON
GO

SET QUOTED_IDENTIFIER ON
GO

DROP view 
 [IBG_Schema].[View - PB - Org Hierarchy By Business Unit]
GO

CREATE view 
 [IBG_Schema].[View - PB - Org Hierarchy By Business Unit]

AS
SELECT 
  '==>' AS [English Org Chart Begins]
, [IBG_Schema].[DG Business Unit].[Business Unit Acronym EN]     
, [IBG_Schema].[DG Business Unit].[Business Unit Full Name EN]   
, [IBG_Schema].[DG Business Unit].[Business Unit Type EN]
, [IBG_Schema].[DG Business Unit].[Part of Organization Code EN] 
, [IBG_Schema].[DG Business Unit].[Business Unit Hyperlink EN]

, '*' AS [Up One Level Parent Break]
, Code_Business_Unit_1.[Business Unit Acronym EN]   AS [Up One Level Parent Acronym EN]
, Code_Business_Unit_1.[Business Unit Full Name EN] AS [Up One Level Parent Full Name EN]

, '**' AS [Up Two Levels Parent Break]
, Code_Business_Unit_2.[Business Unit Acronym EN]   AS [Up Two Levels Parent Acronym EN]
, Code_Business_Unit_2.[Business Unit Full Name EN] AS [Up Two Levels Parent Full Name EN]

, '***' AS [Up Three Levels Parent Break]
, Code_Business_Unit_3.[Business Unit Acronym EN]   AS [Up Three Levels Parent Acronym EN]
, Code_Business_Unit_3.[Business Unit Full Name EN] AS [Up Three Levels Parent Full Name EN]

, '****' AS [Up Four Levels Parent Break]
, Code_Business_Unit_4.[Business Unit Acronym EN]   AS [Up Four Levels Parent Acronym EN]
, Code_Business_Unit_4.[Business Unit Full Name EN] AS [Up Four Levels Parent Full Name EN]

, '*****' AS [Up Five Levels Parent Break]
, Code_Business_Unit_5.[Business Unit Acronym EN]   AS [Up Five Levels Parent Acronym EN]
, Code_Business_Unit_5.[Business Unit Full Name EN] AS [Up Five Levels Parent Full Name EN]

, '==>' AS [Second Language Org Chart Begins]
, [IBG_Schema].[DG Business Unit].[Business Unit Acronym 2NDL] 
, [IBG_Schema].[DG Business Unit].[Business Unit Full Name 2NDL]
, [IBG_Schema].[Code Business Unit Type].[Business Unit Type 2NDL]
, [IBG_Schema].[Code Part of Organization].[Part Of Organization Code 2NDL]
, [IBG_Schema].[DG Business Unit].[Business Unit Hyperlink 2NDL]

, '*' AS [Up One Level Second Language Parent Break]
, Code_Business_Unit_1.[Business Unit Acronym 2NDL]   AS [Up One Level Parent Acronym 2NDL]
, Code_Business_Unit_1.[Business Unit Full Name 2NDL] AS [Up One Level Parent Full Name 2NDL]

, '**' AS [Up Two Levels Second Language Parent Break]
, Code_Business_Unit_2.[Business Unit Acronym 2NDL]   AS [Up Two Levels Parent Acronym 2NDL]
, Code_Business_Unit_2.[Business Unit Full Name 2NDL] AS [Up Two Levels Parent Full Name 2NDL]

, '***' AS [Up Three Levels Second Language Parent Break]
, Code_Business_Unit_3.[Business Unit Acronym 2NDL]    AS [Up Three Levels Parent Acronym 2NDL]
, Code_Business_Unit_3.[Business Unit Full Name 2NDL]  AS [Up Three Levels Parent Full Name 2NDL]

, '****' AS [Up Four Levels Second Language Parent Break]
, Code_Business_Unit_4.[Business Unit Acronym 2NDL]    AS [Up Four Levels Parent Acronym 2NDL]
, Code_Business_Unit_4.[Business Unit Full Name 2NDL]  AS [Up Four Levels Parent Full Name 2NDL]

, '*****' AS [Up Five Levels Second Language Parent Break]
, Code_Business_Unit_5.[Business Unit Acronym 2NDL]    AS [Up Five Levels Parent Acronym 2NDL]
, Code_Business_Unit_5.[Business Unit Full Name 2NDL]  AS [Up Five Levels Parent Full Name 2NDL]

, SYSDATETIME() AS [IBG Publish Date]

FROM 
  [IBG_Schema].[Code Part of Organization] 
  INNER JOIN 
  ([IBG_Schema].[Code Business Unit Type] 
  INNER JOIN 
  ([IBG_Schema].[DG Business Unit] AS Code_Business_Unit_5 
  INNER JOIN 
  ([IBG_Schema].[DG Business Unit] AS Code_Business_Unit_4 
  INNER JOIN 
  ([IBG_Schema].[DG Business Unit] AS Code_Business_Unit_3 
  INNER JOIN 
  ([IBG_Schema].[DG Business Unit] AS Code_Business_Unit_2 
  INNER JOIN 
  ([IBG_Schema].[DG Business Unit] AS Code_Business_Unit_1 
  INNER JOIN 
  [IBG_Schema].[DG Business Unit] 

  ON Code_Business_Unit_1.[Business Unit Acronym EN] = [IBG_Schema].[DG Business Unit].[Parent Business Unit Acronym EN]) 
  ON Code_Business_Unit_2.[Business Unit Acronym EN] = Code_Business_Unit_1.[Parent Business Unit Acronym EN]) 
  ON Code_Business_Unit_3.[Business Unit Acronym EN] = Code_Business_Unit_2.[Parent Business Unit Acronym EN]) 
  ON Code_Business_Unit_4.[Business Unit Acronym EN] = Code_Business_Unit_3.[Parent Business Unit Acronym EN]) 
  ON Code_Business_Unit_5.[Business Unit Acronym EN] = Code_Business_Unit_4.[Parent Business Unit Acronym EN]) 

  ON [IBG_Schema].[Code Business Unit Type].[Business Unit Type EN]          = [IBG_Schema].[DG Business Unit].[Business Unit Type EN]) 
  ON [IBG_Schema].[Code Part of Organization].[Part of Organization Code EN] = [IBG_Schema].[DG Business Unit].[Part of Organization Code EN]

GO
